---
title: mq listener
keywords: documentation
layout: documentation
sidebar: mq_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a MQ listener.

Here is an example on how you should use this:
    mq_listener { 'IIB10QM/SYSTEM.DEFAULT.LISTENER.TCP':
      ensure  => 'present',
      backlog => '0',
      control => 'MANUAL',
      port    => '0',
      trptype => 'TCP',
    }

## Attributes



Attribute Name                    | Short Description                                                                                                        |
--------------------------------- | ------------------------------------------------------------------------------------------------------------------------ |
[adapter](#mq_listener_adapter)   | The adapter number on which NetBIOS listens.                                                                             |
[backlog](#mq_listener_backlog)   | The number of concurrent connection requests that the listener supports.                                                 |
[commands](#mq_listener_commands) | The number of commands that the listener can use.                                                                        |
[control](#mq_listener_control)   | Specifies how the listener is to be started and stopped.                                                                 |
[descr](#mq_listener_descr)       | Plain-text comment.                                                                                                      |
[ensure](#mq_listener_ensure)     | The basic property that the resource should be in.                                                                       |
[ipaddr](#mq_listener_ipaddr)     | IP address for the listener specified in IPv4 dotted decimal, IPv6 hexadecimal notation, or alphanumeric host name form. |
[listener](#mq_listener_listener) | The name of the listsner
                                                                                                |
[loclname](#mq_listener_loclname) | The NetBIOS local name that the listener uses.                                                                           |
[name](#mq_listener_name)         | The full name of the listener.                                                                                           |
[ntbnames](#mq_listener_ntbnames) | The number of names that the listener can use.                                                                           |
[port](#mq_listener_port)         | The port number for TCP/IP.                                                                                              |
[provider](#mq_listener_provider) | resource.                                                                                                                |
[qmgr](#mq_listener_qmgr)         | The name of the queue manager containing the specfied queue.                                                             |
[sessions](#mq_listener_sessions) | The number of sessions that the listener can use.                                                                        |
[socket](#mq_listener_socket)     | The SPX socket on which to listen.                                                                                       |
[status](#mq_listener_status)     | The status of the Listener.                                                                                              |
[tpname](#mq_listener_tpname)     | The LU 6.2 transaction program name (maximum length 64 characters).                                                      |
[trptype](#mq_listener_trptype)   | The transmission protocol to be used.                                                                                    |




### adapter<a name='mq_listener_adapter'>

The adapter number on which NetBIOS listens. This parameter is valid only on Windows when TRPTYPE is NETBIOS.



[Back to overview of mq_listener](#attributes)

### backlog<a name='mq_listener_backlog'>

The number of concurrent connection requests that the listener supports.



[Back to overview of mq_listener](#attributes)

### commands<a name='mq_listener_commands'>

The number of commands that the listener can use. This parameter is valid only on Windows when TRPTYPE is NETBIOS.



[Back to overview of mq_listener](#attributes)

### control<a name='mq_listener_control'>

Specifies how the listener is to be started and stopped.

Valid values are:
- MANUAL    The listener is not to be started automatically or stopped automatically. It is to be controlled by use of the START LISTENER and STOP LISTENER commands.
- QMGR      The listener being defined is to be started and stopped at the same time as the queue manager is started and stopped.
- STARTONLY The listener is to be started at the same time as the queue manager is started, but is not requested to stop when the queue manager is stopped.

Valid values are `MANUAL`, `QMGR`, `STARTONLY`. 

[Back to overview of mq_listener](#attributes)

### descr<a name='mq_listener_descr'>

Plain-text comment. It provides descriptive information about the listener when an operator issues the DISPLAY LISTENER command (see DISPLAY LISTENER ).
It should contain only displayable characters. The maximum length is 64 characters. In a DBCS installation, it can contain DBCS characters (subject to a maximum length of 64 bytes).

Note
If characters are used that are not in the coded character set identifier (CCSID) for this queue manager, they might be translated incorrectly if the information is sent to another queue manager.



[Back to overview of mq_listener](#attributes)

### ensure<a name='mq_listener_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of mq_listener](#attributes)

### ipaddr<a name='mq_listener_ipaddr'>

IP address for the listener specified in IPv4 dotted decimal, IPv6 hexadecimal notation, or alphanumeric host name form. If you do not specify a value for this parameter, the listener listens on all configured IPv4 and IPv6 stacks.



[Back to overview of mq_listener](#attributes)

### listener<a name='mq_listener_listener'>

The name of the listsner



[Back to overview of mq_listener](#attributes)

### loclname<a name='mq_listener_loclname'>

The NetBIOS local name that the listener uses. This parameter is valid only on Windows when TRPTYPE is NETBIOS



[Back to overview of mq_listener](#attributes)

### name<a name='mq_listener_name'>

The full name of the listener. A listener's full name constists of the name of the
Queue manager a slash and then the name of the listener. Here is an example:

    QMGR1/SYSTEM.DEFAULT.LISTENER.TCP



[Back to overview of mq_listener](#attributes)

### ntbnames<a name='mq_listener_ntbnames'>

The number of names that the listener can use. This parameter is valid only on Windows when TRPTYPE is NETBIOS.



[Back to overview of mq_listener](#attributes)

### port<a name='mq_listener_port'>

The port number for TCP/IP. This is valid only when TRPTYPE is TCP. It must not exceed 65535.



[Back to overview of mq_listener](#attributes)

### provider<a name='mq_listener_provider'>

The specific backend to use for this `mq_listener`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage MQ listners



[Back to overview of mq_listener](#attributes)

### qmgr<a name='mq_listener_qmgr'>

The name of the queue manager containing the specfied queue.



[Back to overview of mq_listener](#attributes)

### sessions<a name='mq_listener_sessions'>

The number of sessions that the listener can use. This parameter is valid only on Windows when TRPTYPE is NETBIOS.



[Back to overview of mq_listener](#attributes)

### socket<a name='mq_listener_socket'>

The SPX socket on which to listen. This is valid only if TRPTYPE is SPX.



[Back to overview of mq_listener](#attributes)

### status<a name='mq_listener_status'>

The status of the Listener.

Here is an example on how to use this:

    mq_listener { 'IIB10QM/SYSTEM.DEFAULT.LISTENER.TCP':
      ensure  => 'present',
      ...
      status  => 'running',
      ...
    }

This will define the listener and directly start it.

Valid values are `stopped`, `running`. 

[Back to overview of mq_listener](#attributes)

### tpname<a name='mq_listener_tpname'>

The LU 6.2 transaction program name (maximum length 64 characters). This parameter is valid only on Windows when TRPTYPE is LU62.



[Back to overview of mq_listener](#attributes)

### trptype<a name='mq_listener_trptype'>

The transmission protocol to be used.
Valid values are:

- LU62    SNA LU 6.2. This is valid only on Windows.
- NETBIOS NetBIOS. This is valid only on Windows.
- SPX     Sequenced packet exchange. This is valid only on Windows.
- TCP     TCP/IP.

Valid values are `LU62`, `NETBIOS`, `SPX`, `TCP`. 

[Back to overview of mq_listener](#attributes)
