---
title: mq manager
keywords: documentation
layout: documentation
sidebar: mq_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a MQ queue manager.

Here is an example on how you should use this:

    mq_manager { 'QM1':
      ensure   => 'present',
      acctcono => 'DISABLED',
      acctint  => '1800',
      acctmqi  => 'OFF',
      acctq    => 'OFF',
      activrec => 'MSG',
      actvcono => 'DISABLED',
      actvtrc  => 'OFF',
      authorev => 'DISABLED',
      ccsid    => '1208',
      certlabl => 'ibmwebspheremqqm1',
      certvpol => 'ANY',
      chad     => 'DISABLED',
      chadev   => 'DISABLED',
      chlauth  => 'ENABLED',
      chlev    => 'DISABLED',
      clwllen  => '100',
      clwlmruc => '999999999',
      clwluseq => 'LOCAL',
      cmdev    => 'DISABLED',
      configev => 'DISABLED',
      connauth => 'SYSTEM.DEFAULT.AUTHINFO.IDPWOS',
      defclxq  => 'SCTQ',
      inhibtev => 'DISABLED',
      ipaddrv  => 'IPV4',
      localev  => 'DISABLED',
      loggerev => 'DISABLED',
      markint  => '5000',
      maxhands => '256',
      maxmsgl  => '4194304',
      maxpropl => 'NOLIMIT',
      maxumsgs => '10000',
      monacls  => 'QMGR',
      monchl   => 'OFF',
      monq     => 'OFF',
      perfmev  => 'DISABLED',
      psclus   => 'ENABLED',
      psmode   => 'ENABLED',
      psnpmsg  => 'DISCARD',
      psnpres  => 'NORMAL',
      psrtycnt => '5',
      pssyncpt => 'IFPER',
      remoteev => 'DISABLED',
      revdns   => 'ENABLED',
      routerec => 'MSG',
      schinit  => 'QMGR',
      scmdserv => 'QMGR',
      sslev    => 'DISABLED',
      sslfips  => 'NO',
      sslkeyr  => '/var/mqm/qmgrs/QM1/ssl/key',
      sslrkeyc => '0',
      statacls => 'QMGR',
      statchl  => 'OFF',
      statint  => '1800',
      statmqi  => 'OFF',
      statq    => 'OFF',
      status   => 'Running',
      strstpev => 'ENABLED',
      suiteb   => 'NONE',
      treelife => '1800',
      trigint  => '999999999',
    }

## Attributes



Attribute Name                               | Short Description                                                                                                                                                                                                          |
-------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
[acctcono](#mq_manager_acctcono)             | Specifies whether applications can override the settings of the ACCTQ and ACCTMQI queue manager parameters.                                                                                                                |
[acctint](#mq_manager_acctint)               | The time interval, in seconds, at which intermediate accounting records are written.                                                                                                                                       |
[acctmqi](#mq_manager_acctmqi)               | Specifies whether accounting information for MQI data is to be collected.                                                                                                                                                  |
[acctq](#mq_manager_acctq)                   | Specifies whether accounting data is to be collected for all queues.                                                                                                                                                       |
[activrec](#mq_manager_activrec)             | Specifies whether activity reports are generated if requested in the message.                                                                                                                                              |
[actvcono](#mq_manager_actvcono)             | Specifies whether applications can override the settings of the ACTVTRC queue manager parameter.                                                                                                                           |
[actvtrc](#mq_manager_actvtrc)               | Specifies whether MQI application activity tracing information is to be collected.                                                                                                                                         |
[adoptmca](#mq_manager_adoptmca)             | [z/OS] Specifies whether an orphaned instance of an MCA restarts immediately when a new inbound channel request matching the ADOPTCHK parameter is detected.                                                               |
[authorev](#mq_manager_authorev)             | Specifies whether authorization (Not Authorized) events are generated.                                                                                                                                                     |
[ccsid](#mq_manager_ccsid)                   | The coded character set identifier for the queue manager.                                                                                                                                                                  |
[certlabl](#mq_manager_certlabl)             | Certificate label for this queue manager to use.                                                                                                                                                                           |
[certvpol](#mq_manager_certvpol)             | Specifies which TLS certificate validation policy is used to validate digital certificates received from remote partner systems.                                                                                           |
[chad](#mq_manager_chad)                     | Specifies whether receiver and server-connection channels can be defined automatically.                                                                                                                                    |
[chadev](#mq_manager_chadev)                 | Specifies whether channel auto-definition events are generated.                                                                                                                                                            |
[chadexit](#mq_manager_chadexit)             | Auto-definition exit name.                                                                                                                                                                                                 |
[chlauth](#mq_manager_chlauth)               | Specifies whether the rules defined by channel authentication records are used.                                                                                                                                            |
[chlev](#mq_manager_chlev)                   | Specifies whether channel events are generated.                                                                                                                                                                            |
[clwldata](#mq_manager_clwldata)             | Cluster workload exit data.                                                                                                                                                                                                |
[clwlexit](#mq_manager_clwlexit)             | Cluster workload exit name.                                                                                                                                                                                                |
[clwllen](#mq_manager_clwllen)               | The maximum number of bytes of message data that is passed to the cluster workload exit.                                                                                                                                   |
[clwlmruc](#mq_manager_clwlmruc)             | The maximum number of most recently used outbound cluster channels.                                                                                                                                                        |
[clwluseq](#mq_manager_clwluseq)             | The attribute applies to queues with the queue attribute CLWLUSEQ set to QMGR.                                                                                                                                             |
[cmdev](#mq_manager_cmdev)                   | Specifies whether command events are generated.                                                                                                                                                                            |
[configev](#mq_manager_configev)             | Specifies whether configuration events are generated.                                                                                                                                                                      |
[connauth](#mq_manager_connauth)             | The name of an authentication information object that is used to provide the location of user ID and password authentication.                                                                                              |
[datapath](#mq_manager_datapath)             | The directory used to hold the data files for a queue manager.                                                                                                                                                             |
[deadq](#mq_manager_deadq)                   | The local name of a dead-letter queue (or undelivered-message queue) on which messages that cannot be routed to their correct destination are put.                                                                         |
[default](#mq_manager_default)               | the default queue manager.                                                                                                                                                                                                 |
[defclxq](#mq_manager_defclxq)               | The DEFCLXQ attribute controls which transmission queue is selected by default by cluster-sender channels to get messages from, to send the messages to cluster-receiver channels.                                         |
[defxmitq](#mq_manager_defxmitq)             | Local name of the default transmission queue on which messages destined for a remote queue manager are put.                                                                                                                |
[descr](#mq_manager_descr)                   | Plain-text comment.                                                                                                                                                                                                        |
[ensure](#mq_manager_ensure)                 | The basic property that the resource should be in.                                                                                                                                                                         |
[expryint](#mq_manager_expryint)             | [z/OS] Specifies how often queues are scanned to discard expired messages.                                                                                                                                                 |
[groupur](#mq_manager_groupur)               | [z/OS] This parameter controls whether CICS and XA client applications can establish transactions with a GROUP unit of recovery disposition.                                                                               |
[igq](#mq_manager_igq)                       | [z/OS] Specifies whether intra-group queuing is used.                                                                                                                                                                      |
[igqaut](#mq_manager_igqaut)                 | [z/OS] Specifies the type of authority checking and, therefore, the user IDs, to be used by the IGQ agent (IGQA).                                                                                                          |
[igquser](#mq_manager_igquser)               | [z/OS] Nominates a user ID to be used by the IGQ agent (IGQA) to establish authority to put messages to a destination queue.                                                                                               |
[imgintvl](#mq_manager_imgintvl)             | The target frequency with which the queue manager automatically writes media images, in minutes since the previous media image for the object.                                                                             |
[imglogln](#mq_manager_imglogln)             | The target size of recovery log, written before the queue-manager automatically writes media images, in number of megabytes since the previous media image for the object.                                                 |
[imgrcovo](#mq_manager_imgrcovo)             | Specifies whether authentication information, channel, client connection, listener, namelist, process, alias queue, remote queue, and service objects are recoverable from a media image, if linear logging is being used. |
[imgrcovq](#mq_manager_imgrcovq)             | Specifies the default IMGRCOVQ attribute for local and permanent dynamic queue objects, when used with this parameter.                                                                                                     |
[imgsched](#mq_manager_imgsched)             | Whether the queue-manager automatically writes media images.                                                                                                                                                               |
[inhibtev](#mq_manager_inhibtev)             | Specifies whether inhibit events are generated.                                                                                                                                                                            |
[ipaddrv](#mq_manager_ipaddrv)               | Specifies which IP protocol is to be used for channel connections.                                                                                                                                                         |
[localev](#mq_manager_localev)               | Specifies whether local error events are generated.                                                                                                                                                                        |
[logfile_pages](#mq_manager_logfile_pages)   | The log data is held in a series of files called log files.                                                                                                                                                                |
[loggerev](#mq_manager_loggerev)             | Specifies whether recovery log events are generated.                                                                                                                                                                       |
[logging](#mq_manager_logging)               |   Specfies the type of logging used.                                                                                                                                                                                       |
[logpath](#mq_manager_logpath)               | The directory used to store log files.                                                                                                                                                                                     |
[luname](#mq_manager_luname)                 | [z/OS] The name of the LU to use for outbound LU 6.2 transmissions.                                                                                                                                                        |
[markint](#mq_manager_markint)               | The time interval, expressed in milliseconds, for which messages marked as browsed by a call to MQGET, with the get message option MQGMO_MARK_BROWSE_CO_OP, are expected to remain mark-browsed.                           |
[maxhands](#mq_manager_maxhands)             | The maximum number of open handles that any one connection can have at the same time.                                                                                                                                      |
[maxmsgl](#mq_manager_maxmsgl)               | The maximum length of messages allowed on queues for this queue manager.                                                                                                                                                   |
[maxpropl](#mq_manager_maxpropl)             | The maximum length of property data in bytes that can be associated with a message.                                                                                                                                        |
[maxumsgs](#mq_manager_maxumsgs)             | The maximum number of uncommitted messages within a sync point.                                                                                                                                                            |
[monacls](#mq_manager_monacls)               | Controls the collection of online monitoring data for auto-defined cluster-sender channels.                                                                                                                                |
[monchl](#mq_manager_monchl)                 | Controls the collection of online monitoring data for channels.                                                                                                                                                            |
[monq](#mq_manager_monq)                     | Controls the collection of online monitoring data for queues.                                                                                                                                                              |
[multi_instance](#mq_manager_multi_instance) | Start an instance of a multi-instance queue manager on the local server, permitting it to be highly available.                                                                                                             |
[name](#mq_manager_name)                     | 
                                                                                                                                                                                                                          |
[parent](#mq_manager_parent)                 | The name of the parent queue manager to which the local queue manager is to connect as its child in a hierarchy.                                                                                                           |
[perfmev](#mq_manager_perfmev)               | Specifies whether performance-related events are generated.                                                                                                                                                                |
[provider](#mq_manager_provider)             | resource.                                                                                                                                                                                                                  |
[psclus](#mq_manager_psclus)                 | Controls whether this queue manager participates in publish subscribe activity across any clusters in which it is a member.                                                                                                |
[psmode](#mq_manager_psmode)                 | Controls whether the publish/subscribe engine and the queued publish/subscribe interface are running.                                                                                                                      |
[psnpmsg](#mq_manager_psnpmsg)               | f the queued publish/subscribe interface cannot process a non-persistent input message it might attempt to write the input message to the dead-letter queue.                                                               |
[psnpres](#mq_manager_psnpres)               | The PSNPRES attribute controls whether the queued publish/subscribe interface writes an undeliverable reply message to the dead-letter queue, or discards the message.                                                     |
[psrtycnt](#mq_manager_psrtycnt)             | If the queued publish/subscribe interface fails to process a command message under sync point, the unit of work is backed out.                                                                                             |
[pssyncpt](#mq_manager_pssyncpt)             | Controls whether the queued publish/subscribe interface processes command messages (publishes or delete publication messages) under sync point.                                                                            |
[remoteev](#mq_manager_remoteev)             | Specifies whether remote error events are generated.                                                                                                                                                                       |
[repos](#mq_manager_repos)                   | The name of a cluster for which this queue manager provides a repository manager service.                                                                                                                                  |
[reposnl](#mq_manager_reposnl)               | The name of a namelist of clusters for which this queue manager provides a repository manager service.                                                                                                                     |
[revdns](#mq_manager_revdns)                 | Controls whether reverse lookup of the hostname from a Domain Name Server (DNS) is done for the IP address from which a channel has connected.                                                                             |
[routerec](#mq_manager_routerec)             | Specifies whether trace-route information is recorded if requested in the message.                                                                                                                                         |
[schinit](#mq_manager_schinit)               | Specifies whether the channel initiator starts automatically when the queue manager starts.                                                                                                                                |
[scmdserv](#mq_manager_scmdserv)             | Specifies whether the command server starts automatically when the queue manager starts.                                                                                                                                   |
[scycase](#mq_manager_scycase)               | [z/OS] Specifies whether the security profiles are uppercase or mixed case.                                                                                                                                                |
[sqqmname](#mq_manager_sqqmname)             | [z/OS] The SQQMNAME attribute specifies whether a queue manager in a queue-sharing group opens a shared queue in the same group directly.                                                                                  |
[sslcrlnl](#mq_manager_sslcrlnl)             | The name of a namelist of authentication information objects which are used to provide certificate revocation locations to allow enhanced TLS certificate checking.                                                        |
[sslcryp](#mq_manager_sslcryp)               | Sets the name of the parameter string required to configure the cryptographic hardware present on the system.                                                                                                              |
[sslev](#mq_manager_sslev)                   | Specifies whether TLS events are generated.                                                                                                                                                                                |
[sslfips](#mq_manager_sslfips)               | This parameter is valid only on [z/OS]z/OS, UNIX, Linux, and Windows systems.                                                                                                                                              |
[sslkeyr](#mq_manager_sslkeyr)               | The name of the Secure Sockets Layer key repository.                                                                                                                                                                       |
[sslrkeyc](#mq_manager_sslrkeyc)             | [z/OS]The number of bytes to be sent and received within an TLS conversation before the secret key is renegotiated.                                                                                                        |
[ssltasks](#mq_manager_ssltasks)             | [z/OS]The number of server subtasks to use for processing TLS calls.                                                                                                                                                       |
[standby](#mq_manager_standby)               | in a multi-instance setup.                                                                                                                                                                                                 |
[statacls](#mq_manager_statacls)             | Specifies whether statistics data is to be collected for auto-defined cluster-sender channels.                                                                                                                             |
[statchl](#mq_manager_statchl)               | Specifies whether statistics data is to be collected for channels.                                                                                                                                                         |
[statint](#mq_manager_statint)               | The time interval, in seconds, at which statistics monitoring data is written to the monitoring queue.                                                                                                                     |
[statmqi](#mq_manager_statmqi)               | Specifies whether statistics monitoring data is to be collected for the queue manager.                                                                                                                                     |
[statq](#mq_manager_statq)                   | Specifies whether statistics data is to be collected for queues.                                                                                                                                                           |
[status](#mq_manager_status)                 | The status of the Queue Manager.                                                                                                                                                                                           |
[strstpev](#mq_manager_strstpev)             | Specifies whether start and stop events are generated.                                                                                                                                                                     |
[suiteb](#mq_manager_suiteb)                 | Specifies whether Suite B-compliant cryptography is used and what strength is required.                                                                                                                                    |
[treelife](#mq_manager_treelife)             | The lifetime, in seconds of non-administrative topics.                                                                                                                                                                     |
[trigint](#mq_manager_trigint)               | A time interval expressed in milliseconds.                                                                                                                                                                                 |




### acctcono<a name='mq_manager_acctcono'>

Specifies whether applications can override the settings of the ACCTQ and ACCTMQI queue manager parameters.

Valid values are:
- DISABLED Applications cannot override the settings of the ACCTQ and ACCTMQI parameters. This is the queue manager's initial default value.
- ENABLED Applications can override the settings of the ACCTQ and ACCTMQI parameters by using the options field of the MQCNO structure of the MQCONNX API call. Changes to this parameter are effective for connections to the queue manager that occur after the change.

This parameter is valid only on IBM i, UNIX, Linux, and Windows systems.

Valid values are `DISABLED`, `ENABLED`. 

[Back to overview of mq_manager](#attributes)

### acctint<a name='mq_manager_acctint'>

The time interval, in seconds, at which intermediate accounting records are written.
Specify a value in the range 1 through 604800.
Changes to this parameter are effective for connections to the queue manager that occur after the change.
This parameter is valid only on IBM i, UNIX, Linux, and Windows systems.



[Back to overview of mq_manager](#attributes)

### acctmqi<a name='mq_manager_acctmqi'>

Specifies whether accounting information for MQI data is to be collected.

valid values are:
- OFF MQI accounting data collection is disabled. This is the queue manager's initial default value.
- ON MQI accounting data collection is enabled.

If queue manager attribute ACCTCONO is set to ENABLED, the value of this parameter can be overridden using the options field of the MQCNO structure.
Changes to this parameter are effective for connections to the queue manager that occur after the change.

This parameter is valid only on IBM i, UNIX, Linux, and Windows systems.

Valid values are `ON`, `OFF`. 

[Back to overview of mq_manager](#attributes)

### acctq<a name='mq_manager_acctq'>

Specifies whether accounting data is to be collected for all queues.

[z/OS]On z/OS, the data collected is class 3 accounting data (thread-level and queue-level accounting).
Valid values are:
- OFF Accounting data collection is disabled for all queues which specify QMGR as the value for their ACCTQ parameter.
- ON Accounting data collection is enabled for all queues which specify QMGR as the value of their ACCTQ parameter. [z/OS]On z/OS systems, you must switch on class 3 accounting by the START TRACE command.
- NONE Accounting data collection for all queues is disabled regardless of the value of the ACCTQ parameter of the queue.

Changes to this parameter are effective only for connections to the queue manager occurring after the change to the parameter.

Valid values are `OFF`, `ON`, `NONE`. 

[Back to overview of mq_manager](#attributes)

### activrec<a name='mq_manager_activrec'>

Specifies whether activity reports are generated if requested in the message.

valid values are:
- DISABLED Activity reports are not generated.
- MSG Activity reports are generated and sent to the reply queue specified by the originator in the message causing the report. This is the queue manager's initial default value.
- QUEUE Activity reports are generated and sent to SYSTEM.ADMIN.ACTIVITY.QUEUE

See [Activity recording](https://www.ibm.com/support/knowledgecenter/en/SSFKSJ_9.0.0/com.ibm.mq.mon.doc/q036630_.htm?view=kc).

Valid values are `DISABLED`, `MSG`, `QUEUE`. 

[Back to overview of mq_manager](#attributes)

### actvcono<a name='mq_manager_actvcono'>

Specifies whether applications can override the settings of the ACTVTRC queue manager parameter.

Valid values are:
- DISABLED Applications cannot override the settings of the ACTVTRC queue manager parameter. This is the queue manager's initial default value.
- ENABLED Applications can override the settings of the ACTVTRC queue manager parameter by using the options field of the MQCNO structure of the MQCONNX API call. Changes to this parameter are effective for connections to the queue manager that occur after the change.

This parameter is valid only on IBM i, UNIX, Linux, and Windows systems.

Valid values are `DISABLED`, `ENABLED`. 

[Back to overview of mq_manager](#attributes)

### actvtrc<a name='mq_manager_actvtrc'>

Specifies whether MQI application activity tracing information is to be collected. See Setting ACTVTRC to control collection of activity trace information.

Valid values are:
- OFF IBM MQ MQI application activity tracing information collection is not enabled. This is the queue manager's initial default value.
- ON IBM MQ MQI application activity tracing information collection is enabled.

If the queue manager attribute ACTVCONO is set to ENABLED, the value of this parameter can be overridden using the options field of the MQCNO structure.
Changes to this parameter are effective for connections to the queue manager that occur after the change.
This parameter is valid only on IBM i, UNIX, Linux, and Windows systems.

Valid values are `OFF`, `ON`. 

[Back to overview of mq_manager](#attributes)

### adoptmca<a name='mq_manager_adoptmca'>

[z/OS] Specifies whether an orphaned instance of an MCA restarts immediately when a new inbound channel request matching the ADOPTCHK parameter is detected.

Valid values are:
- ALL Adopt all channel types. This is the queue manager's initial default value.
- NO Adoption of orphaned channels is not required.

This parameter is valid on z/OS only
Changes to this parameter take effect the next time that a channel attempts to adopt an MCA.

Valid values are `ALL`, `NO`. 

[Back to overview of mq_manager](#attributes)

### authorev<a name='mq_manager_authorev'>

Specifies whether authorization (Not Authorized) events are generated.

Valid values are:
- DISABLED Authorization events are not generated. This is the queue manager's initial default value.
- ENABLED Authorization events are generated.

[z/OS]This value is not supported on z/OS.

Valid values are `DISABLED`, `ENABLED`. 

[Back to overview of mq_manager](#attributes)

### ccsid<a name='mq_manager_ccsid'>

The coded character set identifier for the queue manager. The CCSID is the identifier used with all character string fields defined by the API. If the CCSID in the message descriptor is set to the value MQCCSI_Q_MGR, the value applies to application data in the body of a message. The value is set when the message is put to a queue.
Specify a value in the range 1 through 65535. The CCSID specifies a value that is defined for use on your platform, and use a character set that is appropriate to the platform.
If you use this parameter to change the CCSID, applications that are running when the change is applied continue to use the original CCSID. Therefore, stop and restart all running applications before you continue including the command server and channel programs. To stop and restart all running applications, stop and restart the queue manager after changing the parameter value.
[z/OS]This parameter is not valid on z/OS. To carry out the equivalent tasks on z/OS, use CSQ6SYSP to set your system parameters.
See [Code page conversion](https://www.ibm.com/support/knowledgecenter/en/SSFKSJ_9.0.0/com.ibm.mq.ref.dev.doc/q104220_.htm?view=kc) for details of the supported CCSIDs for each platform.



[Back to overview of mq_manager](#attributes)

### certlabl<a name='mq_manager_certlabl'>

Certificate label for this queue manager to use. The label identifies which personal certificate in the key repository has been selected.
The default and migrated queue manager values are:
[z/OS]On z/OS: ibmWebSphereMQXXXX where XXXX is the queue manager name.
On IBM i:
If you specified SSLKEYR(*SYSTEM), the value is blank.
Note that it is forbidden to use a nonblank queue manager CERTLABL with SSLKEYR(*SYSTEM). Attempting to do so results in an MQRCCF_Q_MGR_ATTR_CONFLICT error.
Otherwise, ibmwebspheremqxxxx where xxxx is the queue manager name folded to lower case.
On UNIX and Linux and Windows, ibmwebspheremqxxxx where xxxx is the queue manager name folded to lower case.
You should specify the preceding values. However, leaving CERTLABL as a blank value on the queue manager is interpreted by the system to mean the default values specified.

**Important**
You must run a REFRESH SECURITY TYPE(SSL) command if you make any changes to CERTLABL on the queue manager. However, you do not need to run the REFRESH SECURITY TYPE(SSL) command if you make any changes to CERTLABL on a channel.



[Back to overview of mq_manager](#attributes)

### certvpol<a name='mq_manager_certvpol'>

Specifies which TLS certificate validation policy is used to validate digital certificates received from remote partner systems. This attribute can be used to control how strictly the certificate chain validation conforms to industry security standards.

Valid values:
- ANY Apply each of the certificate validation policies supported by the secure sockets library and accept the certificate chain if any of the policies considers the certificate chain valid. This setting can be used for maximum backwards compatibility with older digital certificates which do not comply with the modern certificate standards.
- RFC5280 Apply only the RFC 5280 compliant certificate validation policy. This setting provides stricter validation than the ANY setting, but rejects some older digital certificates.

For more information about certificate validation policies, see Certificate validation policies in IBM MQ.
This parameter is valid on only UNIX, Linux, and Windows. Changes to the parameter take effect only after a REFRESH SECURITY TYPE(SSL) command is issued.

Valid values are `ANY`, `RFC5280`. 

[Back to overview of mq_manager](#attributes)

### chad<a name='mq_manager_chad'>

Specifies whether receiver and server-connection channels can be defined automatically.
Valid values are:
- DISABLED Auto-definition is not used. This is the queue manager's initial default value.
- ENABLED Auto-definition is used.

Cluster-sender channels can always be defined automatically, regardless of the setting of this parameter.
[z/OS]This parameter is not valid on z/OS.

Valid values are `DISABLED`, `ENABLED`. 

[Back to overview of mq_manager](#attributes)

### chadev<a name='mq_manager_chadev'>

Specifies whether channel auto-definition events are generated.

Valid values are:
- DISABLED Auto-definition events are not generated. This is the queue manager's initial default value.
- ENABLED Auto-definition events are generated.

[z/OS]This parameter is not valid on z/OS.

Valid values are `DISABLED`, `ENABLED`. 

[Back to overview of mq_manager](#attributes)

### chadexit<a name='mq_manager_chadexit'>

Auto-definition exit name.
If this name is nonblank, the exit is called when an inbound request for an undefined receiver, server-connection, or cluster-sender channel is received. It is also called when starting a cluster-receiver channel.
The format and maximum length of the name depends on the environment:
- On Windows, it is of the form dllname(functionname) where dllname is specified without the suffix .DLL. The maximum length is 128 characters.
- On IBM i, it is of the form:progname libname where program name occupies the first 10 characters and libname the second 10 characters (both blank-padded to the right if necessary). The maximum length of the string is 20 characters.
- On UNIX, and Linux, it is of the form libraryname(functionname). The maximum length is 128 characters.

[z/OS]On z/OS, it is a load module name, the maximum length is eight characters.
[z/OS]On z/OS, this parameter applies only to cluster-sender and cluster-receiver channels.



[Back to overview of mq_manager](#attributes)

### chlauth<a name='mq_manager_chlauth'>

Specifies whether the rules defined by channel authentication records are used. CHLAUTH rules can still be set and displayed regardless of the value of this attribute.
Changes to this parameter take effect the next time that an inbound channel attempts to start.
Channels that are currently started are unaffected by changes to this parameter.
Valid values are:
- DISABLED Channel authentication records are not checked.
- ENABLED Channel authentication records are checked.

Valid values are `DISABLED`, `ENABLED`. 

[Back to overview of mq_manager](#attributes)

### chlev<a name='mq_manager_chlev'>

Specifies whether channel events are generated.
Valid values are:
- DISABLED Channel events are not generated.This is the queue manager's initial default value.
- ENABLED All channel events are generated.
- EXCEPTION All exception channel events are generated.

Valid values are `DISABLED`, `ENABLED`, `EXCEPTION`. 

[Back to overview of mq_manager](#attributes)

### clwldata<a name='mq_manager_clwldata'>

Cluster workload exit data. The maximum length of the string is 32 characters.
This string is passed to the cluster workload exit when it is called.



[Back to overview of mq_manager](#attributes)

### clwlexit<a name='mq_manager_clwlexit'>

Cluster workload exit name.
If this name is nonblank, the exit is called when a message is put to a cluster queue. The format and maximum length of the name depends on the environment:
- On UNIX and Linux systems, it is of the form libraryname(functionname). The maximum length is 128 characters.
- On Windows, it is of the form dllname(functionname), where dllname is specified without the suffix .DLL. The maximum length is 128 characters.
- [z/OS]On z/OS, it is a load module name. The maximum length is eight characters.

On IBM i, it is of the form: progname libname

where program name occupies the first 10 characters and libname the second 10 characters (both blank-padded to the right if necessary). The maximum length is 20 characters.
This parameter is valid only on IBM i, z/OS, UNIX, Linux, and Windows.



[Back to overview of mq_manager](#attributes)

### clwllen<a name='mq_manager_clwllen'>

The maximum number of bytes of message data that is passed to the cluster workload exit.
Specify a value in the range:
[z/OS]0 - 100 MB on IBM MQ for z/OS systems
0 - 999,999,999 on distributed platforms
This parameter is valid only on IBM i, z/OS, UNIX, Linux, and Windows.



[Back to overview of mq_manager](#attributes)

### clwlmruc<a name='mq_manager_clwlmruc'>

The maximum number of most recently used outbound cluster channels.
Specify a value in the range 1 through 999,999,999.
See [CLWLMRUC queue manager attribute](https://www.ibm.com/support/knowledgecenter/en/SSFKSJ_9.0.0/com.ibm.mq.ref.con.doc/q082440_.htm?view=kc).



[Back to overview of mq_manager](#attributes)

### clwluseq<a name='mq_manager_clwluseq'>

The attribute applies to queues with the queue attribute CLWLUSEQ set to QMGR. It specifies the behavior of an MQPUT operation when the target queue has a local instance and at least one remote cluster instance. It does not apply if the MQPUT originates from a cluster channel.
Specify either:
- LOCAL The local queue is the only target for MQPUT operations. This is the queue manager's initial default value.
- ANY The queue manager treats the local queue as another instance of the cluster queue for the purposes of workload distribution.

See [CLWLUSEQ queue manager attribute](https://www.ibm.com/support/knowledgecenter/en/SSFKSJ_9.0.0/com.ibm.mq.ref.con.doc/q082430_.htm?view=kc).

Valid values are `LOCAL`, `ANY`. 

[Back to overview of mq_manager](#attributes)

### cmdev<a name='mq_manager_cmdev'>

Specifies whether command events are generated. Valid values are:
- DISABLED Command events are not generated. This is the queue manager's initial default value.
- ENABLED Command events are generated for all successful commands.
- NODISPLAY Command events are generated for all successful commands, other than DISPLAY commands.

Valid values are `DISABLED`, `ENABLED`, `NODISPLAY`. 

[Back to overview of mq_manager](#attributes)

### configev<a name='mq_manager_configev'>

Specifies whether configuration events are generated. Valid values are:
- ENABLED Configuration events are generated. After setting this value, issue REFRESH QMGR TYPE(CONFIGEV) commands for all objects to bring the queue manager configuration up to date.
- DISABLED Configuration events are not generated. This is the queue manager's initial default value.

Valid values are `ENABLED`, `DISABLED`. 

[Back to overview of mq_manager](#attributes)

### connauth<a name='mq_manager_connauth'>

The name of an authentication information object that is used to provide the location of user ID and password authentication. If CONNAUTH is blank, no user ID and password checking is done by the queue manager. The maximum length of the string is MQ_AUTH_INFO_NAME_LENGTH.
Only authentication information objects with type IDPWOS or IDPWLDAP can be specified; other types result in an error message when the OAM (on UNIX, Linux, and Windows platforms)[z/OS] or the security component (on z/OS platforms) reads the configuration. Changes to this configuration, or the object to which it refers, take effect when a REFRESH SECURITY TYPE(CONNAUTH) command is issued.
If you leave CONNAUTH blank, and attempt to connect to a channel that has either REQDADM[z/OS] (on platforms other than z/OS ) or REQUIRED set in the CHCKCLNT field, the connection fails.



[Back to overview of mq_manager](#attributes)

### datapath<a name='mq_manager_datapath'>

The directory used to hold the data files for a queue manager.
In IBM MQ for Windows systems, the default is C:\ProgramData\IBM\MQ\qmgrs (assuming that C: is your data drive). If the volume supports file security, the SYSTEM ID, Administrators, and mqm group must be granted read/write access to the directory.

In IBM MQ for UNIX and Linux systems, the default is /var/mqm/qmgrs. User ID mqm and group mqm must have full authorities to the log files.

The DataPath parameter is provided to assist in the configuration of multi-instance queue managers. For example, on UNIX and Linux systems: if the /var/mqm directory is located on a local file system, use the DataPath parameter and the LogPath parameter to point to the shared file systems accessible to multiple queue managers.

Note:
A queue manager created using DataPath parameter runs on versions of IBM MQ earlier than Version 7.0.1, but the queue manager must be reconfigured to remove the DataPath parameter. You have two options to restore the queue manager to a pre-Version 7.0.1 configuration and run without the DataPath parameter: If you are confident about editing queue manager configurations, you can manually configure the queue manager using the Prefix queue manager configuration parameter. Alternatively, complete the following steps to edit the queue manager:

1 Stop the queue manager.
2 Save the queue manager data and log directories.
3 Delete the queue manager.
4 Backout IBM MQ to the pre-v7.0.1 fix level.
5 Create the queue manager with the same name.
6 Replace the new queue manager data and log directories with the ones you saved.



[Back to overview of mq_manager](#attributes)

### deadq<a name='mq_manager_deadq'>

The local name of a dead-letter queue (or undelivered-message queue) on which messages that cannot be routed to their correct destination are put.
The queue named must be a local queue; see Rules for naming IBM MQ objects.



[Back to overview of mq_manager](#attributes)

### default<a name='mq_manager_default'>

You set this parameter to `true` when you want this queue manager
the default queue manager. The new queue manager replaces any
existing default queue manager.

Valid values are `true`, `false`. 

[Back to overview of mq_manager](#attributes)

### defclxq<a name='mq_manager_defclxq'>

The DEFCLXQ attribute controls which transmission queue is selected by default by cluster-sender channels to get messages from, to send the messages to cluster-receiver channels.
Valid values are:
- SCTQ All cluster-sender channels send messages from SYSTEM.CLUSTER.TRANSMIT.QUEUE. The correlID of messages placed on the transmission queue identifies which cluster-sender channel the message is destined for. SCTQ is set when a queue manager is defined. This behavior is implicit in versions of IBM WebSphere MQ, earlier than Version 7.5. In earlier versions, the queue manager attribute DEFCLXQ was not present.
- CHANNEL Each cluster-sender channel sends messages from a different transmission queue. Each transmission queue is created as a permanent dynamic queue from the model queue SYSTEM.CLUSTER.TRANSMIT.MODEL.QUEUE.

If the queue manager attribute, DEFCLXQ, is set to CHANNEL,the default configuration is changed to cluster-sender channels being associated with individual cluster transmission queues. The transmission queues are permanent-dynamic queues created from the model queue SYSTEM.CLUSTER.TRANSMIT.MODEL.QUEUE. Each transmission queue is associated with one cluster-sender channel. As one cluster-sender channel services a cluster transmission queue, the transmission queue contains messages for only one queue manager in one cluster. You can configure clusters so that each queue manager in a cluster contains only one cluster queue. In this case, the message traffic from a queue manager to each cluster queue is transferred separately from messages to other queues.

Valid values are `SCTQ`, `CHANNEL`. 

[Back to overview of mq_manager](#attributes)

### defxmitq<a name='mq_manager_defxmitq'>

Local name of the default transmission queue on which messages destined for a remote queue manager are put. The default transmission queue is used if there is no other suitable transmission queue defined.
The cluster transmission queue must not be used as the default transmission queue of the queue manager.
The queue named must be a local transmission queue; see [Rules for naming IBM MQ objects](https://www.ibm.com/support/knowledgecenter/en/SSFKSJ_9.0.0/com.ibm.mq.pro.doc/q003340_.htm?view=kc).



[Back to overview of mq_manager](#attributes)

### descr<a name='mq_manager_descr'>

Plain-text comment. It provides descriptive information about the queue manager.
It contains only displayable characters. The maximum length of the string is 64 characters. In a DBCS installation, it can contain DBCS characters (subject to a maximum length of 64 bytes).
If the characters in the descriptive information are in the coded character set identifier (CCSID) for this queue manager they are translated correctly. They are translated when the descriptive information is sent to another queue manager. If they are not in the CCSID for this queue manager, they might be translated incorrectly.



[Back to overview of mq_manager](#attributes)

### ensure<a name='mq_manager_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of mq_manager](#attributes)

### expryint<a name='mq_manager_expryint'>

[z/OS] Specifies how often queues are scanned to discard expired messages.
Valid values are:
- OFF Queues are not scanned. No internal expiry processing is performed.
- integer The approximate interval in seconds at which queues are scanned. Each time that the expiry interval is reached, the queue manager looks for candidate queues that are worth scanning to discard expired messages. The queue manager maintains information about the expired messages on each queue, and therefore whether a scan for expired messages is worthwhile. So, only a selection of queues is scanned at any time. The value must be in the range 1 through 99999999. The minimum scan interval used is 5 seconds, even if you specify a lower value.

You must set the same EXPRYINT value for all queue managers within a queue-sharing group that support this attribute. Shared queues are scanned by only one queue manager in a queue-sharing group. This queue manager is either the first queue manager to restart, or the first queue manager for which EXPRYINT is set.
Changes to EXPRYINT take effect when the current interval expires. Changes also take effect if the new interval is less than the unexpired portion of the current interval. In this case, a scan is scheduled and the new interval value takes immediate effect.
This parameter is valid only on z/OS.



[Back to overview of mq_manager](#attributes)

### groupur<a name='mq_manager_groupur'>

[z/OS] This parameter controls whether CICS and XA client applications can establish transactions with a GROUP unit of recovery disposition.
This parameter is valid only on z/OS. The property can be enabled only when the queue manager is a member of a queue-sharing group.
Valid values are:
- ENABLED CICS and XA client applications can establish transactions with a group unit of recovery disposition by specifying a queue-sharing group name when they connect.
- DISABLED CICS and XA client applications must connect using a queue manager name.

Valid values are `ENABLED`, `DISABLED`. 

[Back to overview of mq_manager](#attributes)

### igq<a name='mq_manager_igq'>

[z/OS] Specifies whether intra-group queuing is used.
This parameter is valid only on z/OS when the queue manager is a member of a queue-sharing group.
Valid values are:
- ENABLED Message transfer between queue managers within a queue-sharing group uses the shared transmission queue, SYSTEM.QSG.TRANSMIT.QUEUE.
- DISABLED Message transfer between queue managers within a queue-sharing group uses non-shared transmission queues and channels. Queue managers that are not part of a queue-sharing group also use this mechanism.

If intra-group queuing is enabled, but the intra-group queuing agent is stopped, issue ALTER QMGR IGQ (ENABLED) to restart it.



[Back to overview of mq_manager](#attributes)

### igqaut<a name='mq_manager_igqaut'>

[z/OS] Specifies the type of authority checking and, therefore, the user IDs, to be used by the IGQ agent (IGQA). This parameter establishes the authority to put messages to a destination queue.
This parameter is valid only on z/OS when the queue manager is a member of a queue-sharing group.
Valid values are:
- DEF Indicates that the default user ID is used to establish authority to put messages to a destination queue. For a one user ID check, the default user ID is the user ID of a queue manager within the queue-sharing group. The default user ID is the user ID of the queue manager that put the messages to the SYSTEM.QSG.TRANSMIT.QUEUE. This user ID is referred to as the QSGSEND user ID. For two user ID checks, the default second user ID is the IGQ user ID.
- CTX Indicates that the user ID from a UserIdentifier field is used to establish authority to put messages to a destination queue. The user ID is the UserIdentifier field in the message descriptor of a message on the SYSTEM.QSG.TRANSMIT.QUEUE. For one user ID check, the QSGSEND user ID is used. For two user ID checks, the QSGSEND user ID, the IGQ user ID and the alternate user ID are used. The alternate user ID is taken from the UserIdentifier field in the message descriptor of a message on the SYSTEM.QSG.TRANSMIT.QUEUE. The alternate user ID is referred to as ALT.
- ONLYIGQ Indicates that only the IGQ user ID is used to establish authority to put messages to a destination queue. For all ID checks, the IGQ user ID is used.
- ALTIGQ Indicates that the IGQ user ID and the ALT user ID are used to establish authority to put messages to a destination queue. For one user ID check, the IGQ user ID is used. For two user ID checks, the IGQ user ID and the ALT user ID are used.

Valid values are `DEF`, `CTX`, `ONLYIGQ`, `ALTIGQ`. 

[Back to overview of mq_manager](#attributes)

### igquser<a name='mq_manager_igquser'>

[z/OS] Nominates a user ID to be used by the IGQ agent (IGQA) to establish authority to put messages to a destination queue. The user ID is referred to as the IGQ user ID.
This parameter is valid only on z/OS when the queue manager is a member of a queue-sharing group. Possible values are:
- Blanks Indicates that the user ID of the receiving queue manager within the queue-sharing group is used.
- Specific user ID Indicates that the user ID specified in the IGQUSER parameter of the receiving queue manager is used.

**Note**
As the receiving queue manager has authority to all queues it can access, security checking might not be performed for this user ID type.
As the value of blanks has a special meaning, you cannot use IGQUSER to specify a real user ID of blanks.



[Back to overview of mq_manager](#attributes)

### imgintvl<a name='mq_manager_imgintvl'>

The target frequency with which the queue manager automatically writes media images, in minutes since the previous media image for the object.
This parameter is not valid on z/OS. Possible values are:
- 1 - 999 999 999 The time in minutes at which the queue manager automatically writes media images. The default value is 60 minutes.
- OFF Automatic media images are not written on a time interval basis.



[Back to overview of mq_manager](#attributes)

### imglogln<a name='mq_manager_imglogln'>

The target size of recovery log, written before the queue-manager automatically writes media images, in number of megabytes since the previous media image for the object. This limits the amount of log to be read when recovering an object.
This parameter is not valid on z/OS. Possible values are:
- 1 - 999 999 999 The target size of the recovery log in megabytes.
- OFF Automatic media images are not written based on the size of log written. OFF is the default value.



[Back to overview of mq_manager](#attributes)

### imgrcovo<a name='mq_manager_imgrcovo'>

Specifies whether authentication information, channel, client connection, listener, namelist, process, alias queue, remote queue, and service objects are recoverable from a media image, if linear logging is being used.
This parameter is not valid on z/OS. Possible values are:
- NO The rcdmqimg andrcrmqobj commands are not permitted for these objects, and automatic media images, if enabled, are not written for these objects.
- YES These objects are recoverable. YES is the default value.

Valid values are `YES`, `NO`. 

[Back to overview of mq_manager](#attributes)

### imgrcovq<a name='mq_manager_imgrcovq'>

Specifies the default IMGRCOVQ attribute for local and permanent dynamic queue objects, when used with this parameter.
This parameter is not valid on z/OS. Possible values are:
- NO The IMGRCOVQ attribute for local and permanent dynamic queue objects is set to NO.
- YES The IMGRCOVQ attribute for local and permanent dynamic queue objects is set to YES. YES is the default value.

Valid values are `YES`, `NO`. 

[Back to overview of mq_manager](#attributes)

### imgsched<a name='mq_manager_imgsched'>

Whether the queue-manager automatically writes media images.
This parameter is not valid on z/OS. Possible values are:
- AUTO The queue-manager attempts to automatically write a media image for an object, before IMGINTVL minutes have elapsed, or IMGLOGLN megabytes of recovery log have been written, since the previous media image for the object was taken. The previous media image might have been taken manually or automatically, depending on the settings of IMGINTVL or IMGLOGLN.
- MANUAL Automatic media images are not written. MANUAL is the default value.

Valid values are `AUTO`, `MANUAL`. 

[Back to overview of mq_manager](#attributes)

### inhibtev<a name='mq_manager_inhibtev'>

Specifies whether inhibit events are generated. The events are generated for Inhibit Get and Inhibit Put)
Valid values are:
- ENABLED Inhibit events are generated.
- DISABLED Inhibit events are not generated. This is the queue manager's initial default value.

Valid values are `ENABLED`, `DISABLED`. 

[Back to overview of mq_manager](#attributes)

### ipaddrv<a name='mq_manager_ipaddrv'>

Specifies which IP protocol is to be used for channel connections.
valid values are:
- IPV4 The IPv4 IP address is to be used. This is the queue manager's initial default value.
- IPV6 The IPv6 IP address is to be used.

This parameter is used only in systems running IPv4 and IPv6. It applies to channels defined only with a TRPTYPE of TCP when either of the following two conditions is true:
The CONNAME parameter of the channel contains a host name that resolves to both an IPv4 and an IPv6 address, and the LOCLADDR parameter is not specified.
The value of the CONNAME and LOCLADDR parameters of the channel is a host name that resolves to both an IPv4 and IPv6 address.

Valid values are `IPV4`, `IPV6`. 

[Back to overview of mq_manager](#attributes)

### localev<a name='mq_manager_localev'>

Specifies whether local error events are generated. Valid values are:
- ENABLED Local error events are generated.
- DISABLED Local error events are not generated. This is the queue manager's initial default value.

Valid values are `ENABLED`, `DISABLED`. 

[Back to overview of mq_manager](#attributes)

### logfile_pages<a name='mq_manager_logfile_pages'>

The log data is held in a series of files called log files. The log
file size is specified in units of 4 KB pages. In IBM MQ for UNIX and
Linux systems, the default number of log file pages is 4096, giving a
log file size of 16 MB. The minimum number of log file pages is 64
and the maximum is 65535.

In IBM MQ for Windows systems, the default number of log file pages is
4096, giving a log file size of 16 MB. The minimum number of log file
pages is 32 and the maximum is 65535.



[Back to overview of mq_manager](#attributes)

### loggerev<a name='mq_manager_loggerev'>

Specifies whether recovery log events are generated. Valid values are:
- DISABLED Logger events are not generated. This is the queue manager's initial default value.
- ENABLED Logger events are generated.

This parameter is valid only on IBM i, UNIX, Linux, and Windows.

Valid values are `DISABLED`, `ENABLED`. 

[Back to overview of mq_manager](#attributes)

### logging<a name='mq_manager_logging'>

  Specfies the type of logging used.

- circular          Use circular logging. This is the default
- linear            Use linear logging.
- linear_automatic  Use linear logging with automatic management of log extents (LogManagement=Automatic).
- linear_archiving  Use linear logging with archive management of log extents (LogManagement=Archive).

Valid values are `circular`, `linear`, `linear_automatic`, `linear_archiving`. 

[Back to overview of mq_manager](#attributes)

### logpath<a name='mq_manager_logpath'>

The directory used to store log files. The default directory to store log paths is defined when you install IBM MQ.
If the volume containing the log file directory supports file security, the log file directory must have access permissions. The permissions allow the user IDs, under whose authority the queue manager runs, read and write access to the directory and its subdirectories. When you install IBM MQ, you grant permissions to the user IDs and to the mqm group on the default log directory. If you set the LogPath parameter to write the log file to a different directory, you must grant the user IDs permission to read and write to the directory. The user ID and permissions for UNIX and Linux are different from those for the Windows system:
**UNIX and Linux**
The directory and its subdirectories must be owned by the user mqm in the group mqm.
If the log file is shared between different instances of the queue manager, the security identifiers (sid) that are used must be the same for the different instances. You must have set the user mqm to the same sid on the different servers running instances of the queue manager. Likewise for the group mqm.

**Windows**
If the directory is accessed by only one instance of the queue manager, you must give read and write access permission to the directory for the following groups and users:
The local group mqm
The local group Administrators
The SYSTEM user ID
To give different instances of a queue manager access to the shared log directory, the queue manager must access the log directory using a global user. Give the global group, which contains the global user, read and write access permission to the log directory. The global group is the additional security access group specified in the -a parameter.

In IBM MQ for Windows systems, the default directory is C:\ProgramData\IBM\MQ\log (assuming that C is your data drive). If the volume supports file security, the SYSTEM ID, Administrators, and mqm group must be granted read/write access to the directory.

In IBM MQ for UNIX and Linux systems, the default directory is /var/mqm/log. User ID mqm and group mqm must have full authorities to the log files.

If you change the locations of these files, you must give these authorities yourself. If these authorities are set automatically, then the log files are in their default locations.



[Back to overview of mq_manager](#attributes)

### luname<a name='mq_manager_luname'>

[z/OS] The name of the LU to use for outbound LU 6.2 transmissions. Set this parameter to be the same as the name of the LU to be used by the listener for inbound transmissions. The maximum length of this parameter is eight characters.
If this name is blank, the APPC/MVS default LU name is used. This name is variable, so LUNAME must always be set if you are using LU 6.2
This parameter is valid on z/OS only.
Changes to this parameter take effect when the channel initiator is restarted.



[Back to overview of mq_manager](#attributes)

### markint<a name='mq_manager_markint'>

The time interval, expressed in milliseconds, for which messages marked as browsed by a call to MQGET, with the get message option MQGMO_MARK_BROWSE_CO_OP, are expected to remain mark-browsed.
If messages are marked for more than approximately MARKINT milliseconds, the queue manager might automatically unmark messages. It might unmark messages that are marked as browsed for the cooperating set of handles.
This parameter does not affect the state of any message marked as browse by a call to MQGET with the get message option MQGMO_MARK_BROWSE_HANDLE.
Specify a value in the range 0 - 999,999,999.
The special value NOLIMIT indicates that the queue manager does not automatically unmark messages by this process.



[Back to overview of mq_manager](#attributes)

### maxhands<a name='mq_manager_maxhands'>

The maximum number of open handles that any one connection can have at the same time.
This value is a value in the range 0 - 999,999,999.



[Back to overview of mq_manager](#attributes)

### maxmsgl<a name='mq_manager_maxmsgl'>

The maximum length of messages allowed on queues for this queue manager.
This value is in the range 32 KB through 100 MB.
Ensure that you also consider the length of any message properties when deciding the value for the MAXMSGL parameter of a channel.
If you reduce the maximum message length for the queue manager, you must also reduce the maximum message length of the SYSTEM.DEFAULT.LOCAL.QUEUE definition. You must also reduce the maximum message length for all other queues defined on the queue manager. This change ensures that the limit of the queue manager is not less than the limit of any of the queues associated with it. If you do not change these lengths, and applications inquire only the MAXMSGL value of the queue, they might not work correctly.
Note that by adding the digital signature and key to the message, [Advanced Message Security](https://www.ibm.com/support/knowledgecenter/en/SSFKSJ_9.0.0/com.ibm.mq.sec.doc/q014580_.htm?view=kc) increases the length of the message.



[Back to overview of mq_manager](#attributes)

### maxpropl<a name='mq_manager_maxpropl'>

The maximum length of property data in bytes that can be associated with a message.
This value is in the range 0 through 100 MB (104 857 600 bytes).
The special value NOLIMIT indicates that the size of the properties is not restricted, except by the upper limit.



[Back to overview of mq_manager](#attributes)

### maxumsgs<a name='mq_manager_maxumsgs'>

The maximum number of uncommitted messages within a sync point.
MAXUMSGS is a limit on the number of messages that can be retrieved, plus the number of messages that can be put, within any single sync point. The limit does not apply to messages that are put or retrieved outside sync point.
The number includes any trigger messages and report messages generated within the same unit of recovery.
If existing applications and queue manager processes are putting and getting a larger number of messages in sync point, reducing MAXUMSGS might cause problems.
[z/OS] An example of queue manager processes that might be affected is clustering on z/OS.
Specify a value in the range 1 through 999,999,999. The default value is 10000.
MAXUMSGS has no effect on MQ Telemetry. MQ Telemetry tries to batch requests to subscribe, unsubscribe, send, and receive messages from multiple clients into batches of work within a transaction.



[Back to overview of mq_manager](#attributes)

### monacls<a name='mq_manager_monacls'>

Controls the collection of online monitoring data for auto-defined cluster-sender channels.
Valid values are:
- QMGR Collection of online monitoring data is inherited from the setting of the MONCHL parameter of the queue manager. This is the queue manager's initial default value.
- OFF Monitoring for the channel is switched off.
- LOW Unless MONCHL is NONE, monitoring is switched on with a low rate of data collection with a minimal effect on system performance. The data collected is not likely to be the most current.
- MEDIUM Unless MONCHL is NONE, monitoring is switched on with a moderate rate of data collection with limited effect on system performance.
- HIGH Unless MONCHL is NONE, monitoring is switched on with a high rate of data collection with a likely effect on system performance. The data collected is the most current available.

A change to this parameter takes effect only on channels started after the change occurs. Any channel started before the change to the parameter continues with the value in force at the time that the channel started.

Valid values are `QMGR`, `OFF`, `LOW`, `MEDIUM`, `HIGH`. 

[Back to overview of mq_manager](#attributes)

### monchl<a name='mq_manager_monchl'>

Controls the collection of online monitoring data for channels. The channels defined with MONCHL(QMGR) are affected by changing the QMGR MONCHL attribute.
Valid values:
- OFF Online monitoring data collection is turned off for channels specifying a value of QMGR in their MONCHL parameter. This is the queue manager's initial default value.
- NONE Online monitoring data collection is turned off for channels regardless of the setting of their MONCHL parameter.
- LOW Online monitoring data collection is turned on, with a low ratio of data collection, for channels specifying a value of QMGR in their MONCHL parameter.
- MEDIUM Online monitoring data collection is turned on, with a moderate ratio of data collection, for channels specifying a value of QMGR in their MONCHL parameter.
- HIGH Online monitoring data collection is turned on, with a high ratio of data collection, for channels specifying a value of QMGR in their MONCHL parameter.

A change to this parameter takes effect only on channels started after the change occurs. Any channel started before the change to the parameter continues with the value in force at the time that the channel started.

Valid values are `QMGR`, `OFF`, `LOW`, `MEDIUM`, `HIGH`. 

[Back to overview of mq_manager](#attributes)

### monq<a name='mq_manager_monq'>

Controls the collection of online monitoring data for queues. Valid values are:
- OFF Online monitoring data collection is turned off for queues specifying a value of QMGR in their MONQ parameter. This is the queue manager's initial default value.
- NONE Online monitoring data collection is turned off for queues regardless of the setting of their MONQ parameter.
- LOW Online monitoring data collection is turned on for queues specifying a value of QMGR in their MONQ parameter.
- MEDIUM Online monitoring data collection is turned on for queues specifying a value of QMGR in their MONQ parameter.
- HIGH Online monitoring data collection is turned on for queues specifying a value of QMGR in their MONQ parameter.

In contrast to MONCHL, there is no distinction between the values LOW, MEDIUM, and HIGH. These values all turn data collection on, but do not affect the rate of collection.
Changes to this parameter are effective only for queues opened after the parameter is changed.

Valid values are `QMGR`, `OFF`, `LOW`, `MEDIUM`, `HIGH`. 

[Back to overview of mq_manager](#attributes)

### multi_instance<a name='mq_manager_multi_instance'>

Start an instance of a multi-instance queue manager on the local server, permitting it to be highly available.
If an instance of the queue manager is not already running elsewhere, the queue manager starts and the instance
becomes active. The active instance is ready to accept local and remote connections to the queue manager on the
local server.

If a multi-instance queue manager instance is already active on a different server the new instance becomes a
standby, permitting it to takeover from the active queue manager instance. While it is in standby, it cannot
accept local or remote connections.

You must not start a second instance of a queue manager on the same server.

The default behavior is to start the instance as a single instance queue manager, forbidding standby instances
from being started.



[Back to overview of mq_manager](#attributes)

### name<a name='mq_manager_name'>





[Back to overview of mq_manager](#attributes)

### parent<a name='mq_manager_parent'>

The name of the parent queue manager to which the local queue manager is to connect as its child in a hierarchy.
A blank value indicates that the queue manager has no parent queue manager.
If there is an existing parent queue manager it is disconnected.
IBM MQ hierarchical connections require that the queue manager attribute PSMODE is set to ENABLED.
The value of PARENT can be set to a blank value if PSMODE is set to DISABLED.
Before a queue manager can connect to a queue manager as its child in a hierarchy, channels must exist in both directions. The channels must exist between the parent queue manager and the child queue manager.
If a parent is already defined, the ALTER QMGR PARENT command disconnects from the original parent and sends a connection flow to the new parent queue manager.
Successful completion of the command does not mean that the action completed. To check that this command has completed, see the ALTER QMGR step in Checking that async commands for distributed networks have finished.



[Back to overview of mq_manager](#attributes)

### perfmev<a name='mq_manager_perfmev'>

Specifies whether performance-related events are generated. Valid values are:
- ENABLED Performance-related events are generated.
- DISABLED Performance-related events are not generated. This is the queue manager's initial default value.
[z/OS]On IBM MQ for z/OS, all the queue managers in a queue-sharing group must have the same setting.

Valid values are `ENABLED`, `DISABLED`. 

[Back to overview of mq_manager](#attributes)

### provider<a name='mq_manager_provider'>

The specific backend to use for this `mq_manager`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage MQ queue managers



[Back to overview of mq_manager](#attributes)

### psclus<a name='mq_manager_psclus'>

Controls whether this queue manager participates in publish subscribe activity across any clusters in which it is a member. No clustered topic objects can exist in any cluster when modifying from ENABLED to DISABLED.
For more information about PSCLUS, see Inhibiting clustered publish/subscribe.
Note
To change a PSCLUS parameter status, the CHIN address space needs to be running. Valid values are:
- ENABLED This queue manager can define clustered topic objects, publish to subscribers on other queue managers, and register subscriptions that receive publications from other queue managers. All queue managers in the cluster running a version of IBM MQ that supports this option must specify PSCLUS(ENABLED) for the publish/subscribe activity to function as expected. ENABLED is the default value when a queue manager is created.
- DISABLED This queue manager cannot define clustered topic objects and ignores their definition on any other queue manager in the cluster. Publications are not forwarded to subscribers elsewhere in the cluster, and subscriptions are not registered other than on the local queue manager. To ensure that no publish/subscribe activity occurs in the cluster, all queue managers must specify PSCLUS(DISABLED). As a minimum, full repositories must be consistent in enabling or disabling publish/subscribe participation.

Valid values are `ENABLED`, `DISABLED`. 

[Back to overview of mq_manager](#attributes)

### psmode<a name='mq_manager_psmode'>

Controls whether the publish/subscribe engine and the queued publish/subscribe interface are running. It controls whether applications can publish or subscribe by using the application programming interface. It also controls whether the queues that are monitored by the queued publish/subscribe interface, are monitored.
Changing the PSMODE attribute can change the PSMODE status. Use DISPLAY PUBSUB, or on IBM i DSPMQM, to determine the current state of the publish/subscribe engine and the queued publish/subscribe interface.
Valid values are:
- COMPAT The publish/subscribe engine is running. It is therefore possible to publish or subscribe by using the application programming interface. The queued publish/subscribe interface is not running. Any publish/subscribe messages put to the queues that are monitored by the queued publish/subscribe interfaces are not acted upon. Use this setting for compatibility with WebSphere Message Broker (now known as IBM Integration Bus ) V6 or earlier versions that use this queue manager.
- DISABLED The publish/subscribe engine and the queued publish/subscribe interface are not running. It is therefore not possible to publish or subscribe by using the application programming interface. Any publish/subscribe messages put to the queues that are monitored by the queued publish/subscribe interfaces are not acted upon. If a queue manager is in a publish/subscribe cluster or hierarchy, it might receive publish/subscribe messages from other queue managers in the cluster or hierarchy. Examples of such messages are publication messages or proxy subscriptions. While PSMODE is set to DISABLED those messages are not processed. For this reason, disable any queue manager in a publish/subscribe cluster or hierarchy only for as long as there is little build-up of messages.
- ENABLED The publish/subscribe engine and the queued publish/subscribe interface are running. It is therefore possible to publish or subscribe by using the application programming interface and the queues that are being monitored by the queued publish/subscribe interface. This is the queue manager's initial default value.

Note
If a queue manager is in a publish/subscribe cluster or hierarchy, and you change PSMODE to ENABLED, you might have to run the command REFRESH QMGR TYPE(PROXY). The command ensures that non-durable subscriptions are known across the cluster or hierarchy when PSMODE is set back to ENABLED. The circumstance in which you must run the command is as follows. If PSMODE is changed from ENABLED to DISABLED and back to ENABLED, and one or more non-durable subscriptions exist across all three stages.

Valid values are `COMPAT`, `DISABLED`, `ENABLED`. 

[Back to overview of mq_manager](#attributes)

### psnpmsg<a name='mq_manager_psnpmsg'>

f the queued publish/subscribe interface cannot process a non-persistent input message it might attempt to write the input message to the dead-letter queue. Whether it attempts to do so depends on the report options of the input message. The attempt to write the input message to the dead-letter queue might fail. In this case, the queued publish/subscribe interface might discard the input message. If MQRO_DISCARD_MSG is specified on the input message, the input message is discarded. If MQRO_DISCARD_MSG is not set, setting PSNPMSG to KEEP prevents the input message from being discarded. The default is to discard the input message.
Note
If you specify a value of IFPER for PSSYNCPT, you must not specify a value of KEEP for PSNPMSG.

Valiud values are:
- DISCARD Non-persistent input messages might be discarded if they cannot be processed.
- KEEP Non-persistent input messages are not discarded if they cannot be processed. In this situation, the queued publish/subscribe interface continues to try to process this message again at appropriate intervals and does not continue processing subsequent messages.

Valid values are `DISCARD`, `KEEP`. 

[Back to overview of mq_manager](#attributes)

### psnpres<a name='mq_manager_psnpres'>

The PSNPRES attribute controls whether the queued publish/subscribe interface writes an undeliverable reply message to the dead-letter queue, or discards the message. The choice is necessary if the queued publish/subscribe interface cannot deliver a reply message to the reply-to queue.
For new queue managers, the initial value is NORMAL. If you specify a value of IFPER for PSSYNCPT, you must not specify a value of KEEP or SAFE for PSNPRES.
For migrated queue managers on IBM i, UNIX, Linux, and Windows systems, the value depends on DLQNonPersistentResponse and DiscardNonPersistentResponse. Valid values are:
- NORMAL Non-persistent responses which cannot be placed on the reply queue are put on the dead-letter queue. If they cannot be placed on the dead-letter queue then they are discarded.
- SAFE Non-persistent responses which cannot be placed on the reply queue are put on the dead-letter queue. If the response cannot be sent and cannot be placed on the dead-letter queue, the queued publish/subscribe interface backs out of the current operation. It tries again at appropriate intervals, and does not continue processing subsequent messages.
- DISCARD Non-persistent responses which cannot be placed on the reply queue are discarded
- KEEP Non-persistent responses are not placed on the dead-letter queue or discarded. Instead the queued publish/subscribe interface backs out the current operation and then tries it again at appropriate intervals and does not continue processing subsequent messages.

Valid values are `NORMAL`, `SAFE`, `DISCARD`, `KEEP`. 

[Back to overview of mq_manager](#attributes)

### psrtycnt<a name='mq_manager_psrtycnt'>

If the queued publish/subscribe interface fails to process a command message under sync point, the unit of work is backed out. The command tries to process the message a number of times again, before the publish/subscribe broker processes the command message according to its report options instead. This situation can arise for a number of reasons. For example, if a publish message cannot be delivered to a subscriber, and it is not possible to put the publication on the dead letter queue.
The initial value for this parameter on a new queue manager is 5.
Range is 0 - 999,999,999.



[Back to overview of mq_manager](#attributes)

### pssyncpt<a name='mq_manager_pssyncpt'>

Controls whether the queued publish/subscribe interface processes command messages (publishes or delete publication messages) under sync point.
Valid values are:
- YES All messages are processed under sync point.
- IFPER Only persistent messages are part of the sync point. The initial value of the queue manager is IFPER.

Valid values are `YES`, `IFPER`. 

[Back to overview of mq_manager](#attributes)

### remoteev<a name='mq_manager_remoteev'>

Specifies whether remote error events are generated. Valid values are:
- DISABLED Remote error events are not generated. This is the queue manager's initial default value.
- ENABLED Remote error events are generated.

[z/OS]If you are using the reduced function form of IBM MQ for z/OS supplied with WebSphere Application Server, only DISABLED is valid.

Valid values are `DISABLED`, `ENABLED`. 

[Back to overview of mq_manager](#attributes)

### repos<a name='mq_manager_repos'>

The name of a cluster for which this queue manager provides a repository manager service. The maximum length is 48 characters conforming to the rules for naming IBM MQ objects.
No more than one of the resultant values of REPOS and REPOSNL can be nonblank.
If you use the REPOS parameter to create a full repository queue manager, connect it to at least one other full repository queue manager in the cluster. Connect it using a cluster-sender channel. See the information in Components of a cluster for details about using cluster-sender channels with full repository queue managers.
This parameter is valid on IBM i, [z/OS]z/OS, UNIX, Linux, and Windows.

Successful completion of the command does not mean that the action completed. To check for true completion, see the ALTER QMGR step in [Checking that async commands for distributed networks have finished](https://www.ibm.com/support/knowledgecenter/en/SSFKSJ_9.0.0/com.ibm.mq.adm.doc/q021225_.htm?view=kc#q021225).



[Back to overview of mq_manager](#attributes)

### reposnl<a name='mq_manager_reposnl'>

The name of a namelist of clusters for which this queue manager provides a repository manager service.
No more than one of the resultant values of REPOS and REPOSNL can be nonblank.
Both REPOS and REPOSNL might be blank, or REPOS might be blank and the namelist specified by REPOSNL is empty. In these cases, this queue manager does not have a full repository. It might be a client of other repository services that are defined in the cluster.
If you use the REPOSNL parameter to create a full repository queue manager, connect it to other full repository queue managers. Connect it to at least one other full repository queue manager in each cluster specified in the namelist using cluster-sender channels. See the information in Components of a cluster for details about using cluster-sender channels with full repository queue managers.
This parameter is valid on IBM i, [z/OS]z/OS, UNIX, Linux, and Windows.

Successful completion of the command does not mean that the action completed. To check for true completion, see the ALTER QMGR step in [Checking that async commands for distributed networks have finished](https://www.ibm.com/support/knowledgecenter/en/SSFKSJ_9.0.0/com.ibm.mq.adm.doc/q021225_.htm?view=kc#q021225).



[Back to overview of mq_manager](#attributes)

### revdns<a name='mq_manager_revdns'>

Controls whether reverse lookup of the hostname from a Domain Name Server (DNS) is done for the IP address from which a channel has connected. This attribute has an effect only on channels using a transport type (TRPTYPE) of TCP:
- ENABLED DNS host names are reverse looked-up for the IP addresses of inbound channels when this information is required. This setting is required for matching against CHLAUTH rules that contain host names, and to include the host name in error messages. The IP address is still included in messages that provide a connection identifier. This is the initial default value for the queue manager.
- DISABLED DNS host names are not reverse looked-up for the IP addresses of inbound channels. With this setting any CHLAUTH rules using host names are not matched.

Valid values are `ENABLED`, `DISABLED`. 

[Back to overview of mq_manager](#attributes)

### routerec<a name='mq_manager_routerec'>

Specifies whether trace-route information is recorded if requested in the message. If this parameter is not set to DISABLED, it controls whether any reply generated is sent to SYSTEM.ADMIN.TRACE.ROUTE.QUEUE, or to the destination specified by the message itself. If ROUTEREC is not DISABLED, messages not yet at the final destination might have information added to them.
Valid values are:
- DISABLED Trace-route information is not recorded.
- MSG Trace-route information is recorded and sent to the destination specified by the originator of the message causing the trace route record. This is the queue manager's initial default value.
- QUEUE Trace-route information is recorded and sent to SYSTEM.ADMIN.TRACE.ROUTE.QUEUE.

Valid values are `DISABLED`, `MSG`, `QUEUE`. 

[Back to overview of mq_manager](#attributes)

### schinit<a name='mq_manager_schinit'>

Specifies whether the channel initiator starts automatically when the queue manager starts.
Valid values are:
- QMGR The channel initiator starts automatically when the queue manager starts.
- MANUAL The channel initiator does not start automatically.

This parameter is valid only on IBM i, UNIX, Linux, and Windows.

Valid values are `QMGR`, `MANUAL`. 

[Back to overview of mq_manager](#attributes)

### scmdserv<a name='mq_manager_scmdserv'>

Specifies whether the command server starts automatically when the queue manager starts.
Valid values are:
- QMGR The command server starts automatically when the queue manager starts.
- MANUAL The command server does not start automatically.

This parameter is valid only on IBM i, UNIX, Linux, and Windows systems.

Valid values are `QMGR`, `MANUAL`. 

[Back to overview of mq_manager](#attributes)

### scycase<a name='mq_manager_scycase'>

[z/OS] Specifies whether the security profiles are uppercase or mixed case. Valid values are:
- UPPER The security profiles are uppercase only. However, MXTOPIC and GMXTOPIC are used for topic security, and can contain mixed-case profiles.
- MIXED The security profiles are mixed case. MQCMDS and MQCONN are used for command and connection security but they can contain only uppercase profiles.

Changes to SCYCASE become effective after you run the following command:
REFFRESH SECURITY(*) TYPE(CLASSES)
This parameter is valid only on z/OS

Valid values are `UPPER`, `MIXED`. 

[Back to overview of mq_manager](#attributes)

### sqqmname<a name='mq_manager_sqqmname'>

[z/OS] The SQQMNAME attribute specifies whether a queue manager in a queue-sharing group opens a shared queue in the same group directly. The processing queue manager calls MQOPEN for a shared queue and sets the ObjectQmgrName parameter for the queue. If the shared queue is in the same queue-sharing group as the processing queue manager, the queue can be opened directly by the processing queue manager. Set the SQQMNAME attribute to control if the queue is opened directly, or by the ObjectQmgrName queue manager. The attribute will also be honored when opening a QALIAS with copy disposition, if the target queue is a shared queue in the same queue-sharing group as the processing queue-manager. In this situation it is important that the QALIAS copy object on each queue-manager in the queue-sharing group has the same target queue.
Valid values are:
- USE The ObjectQmgrName is used, and the appropriate transmission queue is opened.
- IGNORE The processing queue manager opens the shared queue directly. Setting the parameter to this value can reduce the traffic in your queue manager network.

This parameter is valid only on z/OS.

Valid values are `USE`, `IGNORE`. 

[Back to overview of mq_manager](#attributes)

### sslcrlnl<a name='mq_manager_sslcrlnl'>

The name of a namelist of authentication information objects which are used to provide certificate revocation locations to allow enhanced TLS certificate checking.
If SSLCRLNL is blank, certificate revocation checking is not invoked unless one of the TLS certificates used contains an AuthorityInfoAccess or CrlDistributionPoint X.509 certificate extension.
Changes to SSLCRLNL, or to the names in a previously specified namelist, or to previously referenced authentication information objects become effective either:
On IBM i, UNIX, Linux, and Windows systems when a new channel process is started.
- For channels that run as threads of the channel initiator on IBM i, UNIX, Linux, and Windows systems, when the channel initiator is restarted.
- For channels that run as threads of the listener on IBM i, UNIX, Linux, and Windows systems, when the listener is restarted.
- [z/OS]On z/OS, when the channel initiator is restarted.
- When a REFRESH SECURITY TYPE(SSL) command is issued.
- On IBM i queue managers, this parameter is ignored. However, it is used to determine which authentication information objects are written to the AMQCLCHL.TAB file.

Only authentication information objects with types of LDAPCRL or OCSP are allowed in the namelist referred to by SSLCRLNL. Any other type results in an error message when the list is processed and is subsequently ignored.



[Back to overview of mq_manager](#attributes)

### sslcryp<a name='mq_manager_sslcryp'>

Sets the name of the parameter string required to configure the cryptographic hardware present on the system.
All supported cryptographic hardware supports the PKCS #11 interface. Specify a string of the following format:
GSK_PKCS11= <the PKCS #11 driver path and file name>
; <the PKCS #11 token label> ;
<the PKCS #11 token password> ; <symmetric cipher setting>
;
The PKCS #11 driver path is an absolute path to the shared library providing support for the PKCS #11 card. The PKCS #11 driver file name is the name of the shared library. An example of the value required for the PKCS #11 driver path and file name is /usr/lib/pkcs11/PKCS11_API.so
To access symmetric cipher operations through GSKit, specify the symmetric cipher setting parameter. The value of this parameter is either:
SYMMETRIC_CIPHER_OFF
Do not access symmetric cipher operations.
SYMMETRIC_CIPHER_ON
Access symmetric cipher operations.
If the symmetric cipher setting parameter is not specified, it has the same effect as specifying SYMMETRIC_CIPHER_OF F.
The maximum length of the string is 256 characters.
If you specify a string that is not in the format listed, you get an error.
When the SSLCRYP value is changed, the cryptographic hardware parameters specified become the ones used for new TLS connection environments. The new information becomes effective:
When a new channel process is started.
For channels that run as threads of the channel initiator, when the channel initiator is restarted.
For channels that run as threads of the listener, when the listener is restarted.
When a REFRESH SECURITY TYPE(SSL) command is issued.



[Back to overview of mq_manager](#attributes)

### sslev<a name='mq_manager_sslev'>

Specifies whether TLS events are generated. Valid values are:
- DISABLED TLS events are not generated. This is the queue manager's initial default value.
- ENABLED All TLS events are generated.

Valid values are `DISABLED`, `ENABLED`. 

[Back to overview of mq_manager](#attributes)

### sslfips<a name='mq_manager_sslfips'>

This parameter is valid only on [z/OS]z/OS, UNIX, Linux, and Windows systems.
SSLFIPS specifies whether only FIPS-certified algorithms are to be used if cryptography is carried out in IBM MQ, rather than in cryptographic hardware. If cryptographic hardware is configured, the cryptographic modules used are those modules provided by the hardware product. These might, or might not, be FIPS-certified to a particular level. Whether the modules are FIPS-certified depends on the hardware product in use. For more information about FIPS, see the Federal Information Processing Standards (FIPS) manual. Valid values are:
- NO If you set SSLFIPS to NO, you can use either FIPS certified or non-FIPS certified CipherSpecs. If the queue manager runs without using cryptographic hardware, refer to the CipherSpecs listed in Specifying CipherSpecs. This is the queue manager's initial default value.
- YES Specifies that only FIPS-certified algorithms are to be used in the CipherSpecs allowed on all TLS connections from and to this queue manager. For a listing of appropriate FIPS 140-2 certified CipherSpecs; see Specifying CipherSpecs.

Changes to SSLFIPS become effective either:
- On UNIX, Linux, and Windows systems, when a new channel process is started.
- For channels that run as threads of the channel initiator on UNIX, Linux, and Windows systems, when the channel initiator is restarted.
- For channels that run as threads of the listener on UNIX, Linux, and Windows systems, when the listener is restarted.
- For channels that run as threads of a process pooling process, when the process pooling process is started or restarted and first runs an TLS channel. If the process pooling process has already run an TLS channel, and you want the change to become effective immediately, run the MQSC command REFRESH SECURITY TYPE(SSL). The process pooling process is amqrmppa on UNIX, Linux, and Windows systems.
- [z/OS]On z/OS, when the channel initiator is restarted.
- When a REFRESH SECURITY TYPE(SSL) command is issued [z/OS], except on z/OS.



[Back to overview of mq_manager](#attributes)

### sslkeyr<a name='mq_manager_sslkeyr'>

The name of the Secure Sockets Layer key repository.
The maximum length of the string is 256 characters.
The format of the name depends on the environment:
- [z/OS]On z/OS, it is the name of a key ring.
- On IBM i, it is of the form pathname/keyfile, where keyfile is specified without the suffix .kdb, and identifies a GSKit key database file.
- If you specify *SYSTEM, IBM MQ uses the system certificate store as the key repository for the queue manager. The queue manager is registered as a server application in the Digital Certificate Manager (DCM). You can assign any server/client certificate in the system store to the queue manager, because you registered it as a server application. If you change the SSLKEYR parameter to a value other than *SYSTEM, IBM MQ unregisters the queue manager as an application with DCM.
- On UNIX and Linux, it is of the form pathname/keyfile and on Windows pathnamekeyfile , where keyfile is specified without the suffix .kdb, and identifies a Java keystore file.
- On IBM i, UNIX, Linux, and Windows systems, the syntax of this parameter is validated to ensure that it contains a valid, absolute, directory path.

If SSLKEYR is blank, channels using TLS fail to start. If SSLKEYR is set to a value that does not correspond to a key ring or key database file, channels using TLS also fail to start.
Changes to SSLKEYR become effective either:
- On IBM i, UNIX, Linux, and Windows systems, when a new channel process is started.
- For channels that run as threads of the channel initiator on IBM i, UNIX, Linux, and Windows systems, when the channel initiator is restarted.
- For channels that run as threads of the listener on IBM i, UNIX, Linux, and Windows systems, when the listener is restarted.
- For channels that run as threads of a process pooling process, amqrmppa, when the process pooling process is started or restarted and first runs a TLS channel. If the process pooling process has already run a TLS channel, and you want the change to become effective immediately, run the MQSC command REFRESH SECURITY TYPE(SSL).
- [z/OS]On z/OS, when the channel initiator is restarted.
- When a REFRESH SECURITY TYPE(SSL) command is issued.



[Back to overview of mq_manager](#attributes)

### sslrkeyc<a name='mq_manager_sslrkeyc'>

[z/OS]The number of bytes to be sent and received within an TLS conversation before the secret key is renegotiated. The number of bytes includes control information.
SSLRKEYC is used only by TLS channels which initiate communication from the queue manager. For example, the sender channel initiates communication in a sender and receiver channel pairing.
If a value greater than zero is specified, the secret key is also renegotiated before message data is sent or received following a channel heartbeat. The count of bytes until the next secret key renegotiation is reset after each successful renegotiation.
Specify a value in the range 0 - 999,999,999. A value of zero means that the secret key is never renegotiated. If you specify an TLS secret key reset count in the range 1 - 32767 bytes (32 KB), TLS channels use a secret key reset count of 32 KB. The larger reset count value avoids the cost of excessive key resets which would occur for small TLS secret key reset values.
Attention
Non-zero values less than 4096 (4 KB) might cause channels to fail to start, or might cause inconsistencies in the values of SSLKEYDA, SSLKEYTI, and SSLRKEYS.



[Back to overview of mq_manager](#attributes)

### ssltasks<a name='mq_manager_ssltasks'>

[z/OS]The number of server subtasks to use for processing TLS calls. To use TLS channels, you must have at least two of these tasks running.
This parameter is valid only on z/OS.
This value is in the range 0 - 9999. To avoid problems with storage allocation, do not set the SSLTASKS parameter to a value greater than 50.
Changes to this parameter are effective when the channel initiator is restarted.



[Back to overview of mq_manager](#attributes)

### standby<a name='mq_manager_standby'>

You set this parameter to `true` when you want to define a second Queue manager
in a multi-instance setup.

Valid values are `true`, `false`. 

[Back to overview of mq_manager](#attributes)

### statacls<a name='mq_manager_statacls'>

Specifies whether statistics data is to be collected for auto-defined cluster-sender channels. Valid values are:
- QMGR Collection of statistics data is inherited from the setting of the STATCHL parameter of the queue manager. This is the queue manager's initial default value.
- OFF Statistics data collection for the channel is switched off.
- LOW Unless STATCHL is NONE, statistics data collection is switched on with a low ratio of data collection with a minimal effect on system performance.
- MEDIUM Unless STATCHL is NONE, statistics data collection is switched on with a moderate ratio of data collection.
- HIGH Unless STATCHL is NONE, statistics data collection is switched on with a high ratio of data collection.

A change to this parameter takes effect only on channels started after the change occurs. Any channel started before the change to the parameter continues with the value in force at the time that the channel started.
[z/OS]On z/OS, this parameter simply turns on statistics data collection, regardless of the value you select. Specifying LOW, MEDIUM, or HIGH makes no difference to your results.

Valid values are `QMGR`, `OFF`, `LOW`, `MEDIUM`, `HIGH`. 

[Back to overview of mq_manager](#attributes)

### statchl<a name='mq_manager_statchl'>

Specifies whether statistics data is to be collected for channels. Valid values are:
- NONE Statistics data collection is turned off for channels regardless of the setting of their STATCHL parameter.
- OFF Statistics data collection is turned off for channels specifying a value of QMGR in their STATCHL parameter. This is the queue manager's initial default value.
- LOW Statistics data collection is turned on, with a low ratio of data collection, for channels specifying a value of QMGR in their STATCHL parameter.
- MEDIUM Statistics data collection is turned on, with a moderate ratio of data collection, for channels specifying a value of QMGR in their STATCHL parameter.
- HIGH Statistics data collection is turned on, with a high ratio of data collection, for channels specifying a value of QMGR in their STATCHL parameter.

A change to this parameter takes effect only on channels started after the change occurs. Any channel started before the change to the parameter continues with the value in force at the time that the channel started.
[z/OS]On z/OS, this parameter simply turns on statistics data collection, regardless of the value you select. Specifying LOW, MEDIUM, or HIGH makes no difference to your results.

Valid values are `NONE`, `OFF`, `LOW`, `MEDIUM`, `HIGH`. 

[Back to overview of mq_manager](#attributes)

### statint<a name='mq_manager_statint'>

The time interval, in seconds, at which statistics monitoring data is written to the monitoring queue.
Specify a value in the range 1 through 604800.
This parameter is valid only on IBM i, UNIX, Linux, and Windows systems.
Changes to this parameter take immediate effect on the collection of monitoring and statistics data.



[Back to overview of mq_manager](#attributes)

### statmqi<a name='mq_manager_statmqi'>

Specifies whether statistics monitoring data is to be collected for the queue manager. Valid values are:
- OFF Data collection for MQI statistics is disabled. This is the queue manager's initial default value.
- ON Data collection for MQI statistics is enabled.

This parameter is valid only on IBM i, UNIX, Linux, and Windows systems.
Changes to this parameter take immediate effect on the collection of monitoring and statistics data.

Valid values are `OFF`, `ON`. 

[Back to overview of mq_manager](#attributes)

### statq<a name='mq_manager_statq'>

Specifies whether statistics data is to be collected for queues. Valid values are:
- NONE Statistics data collection is turned off for queues regardless of the setting of their STATQ parameter.
- OFF Statistics data collection is turned off for queues specifying a value of QMGR or OFF in their STATQ parameter. OFF is the default value.
- ON Statistics data collection is turned on for queues specifying a value of QMGR or ON in their STATQ parameter.

This parameter is valid only on IBM i, UNIX, Linux, and Windows systems.
Statistics messages are generated only for queues which are opened after statistics collection is enabled. You do not need to restart the queue manager for the new value of STATQ to take effect.

Valid values are `NONE`, `OFF`, `ON`. 

[Back to overview of mq_manager](#attributes)

### status<a name='mq_manager_status'>

The status of the Queue Manager.

Valid values are `Starting`, `Running`, `Stopped`, `Running as standby`, `Running elsewhere`, `Quiescing`, `Ending immediately`, `Ending pre-emptively`, `Ended normally`, `Ended immediately`, `Ended unexpectedly`, `Ended pre-emptively`, `Status not available`. 

[Back to overview of mq_manager](#attributes)

### strstpev<a name='mq_manager_strstpev'>

Specifies whether start and stop events are generated. Valid values are:
- ENABLED Start and stop events are generated. This is the queue manager's initial default value.
- DISABLED Start and stop events are not generated.

Valid values are `ENABLED`, `DISABLED`. 

[Back to overview of mq_manager](#attributes)

### suiteb<a name='mq_manager_suiteb'>

Specifies whether Suite B-compliant cryptography is used and what strength is required.
Valid values are:
- NONE Suite B is not used. NONE is the default
- 128_BIT Suite B 128-bit level security is used.
- 192_BIT Suite B 192-bit level security is used
- 128_BIT,192_BIT Both Suite B 128-bit and 192-bit level security is used

Valid values are `NONE`, `128_BIT`, `192_BIT`, `128_BIT,192_BIT`. 

[Back to overview of mq_manager](#attributes)

### treelife<a name='mq_manager_treelife'>

The lifetime, in seconds of non-administrative topics.
Non-administrative topics are those topics created when an application publishes to, or subscribes on, a topic string that does not exist as an administrative node. When this non-administrative node no longer has any active subscriptions, this parameter determines how long the queue manager waits before removing that node. Only non-administrative topics that are in use by a durable subscription remain after the queue manager is recycled.
Specify a value in the range 0 through 604000. A value of 0 means that non-administrative topics are not removed by the queue manager.



[Back to overview of mq_manager](#attributes)

### trigint<a name='mq_manager_trigint'>

A time interval expressed in milliseconds.
The TRIGINT parameter is relevant only if the trigger type ( TRIGTYPE ) is set to FIRST (see DEFINE QLOCAL for details). In this case trigger messages are normally generated only when a suitable message arrives on the queue, and the queue was previously empty. Under certain circumstances, however, an additional trigger message can be generated with FIRST triggering even if the queue was not empty. These additional trigger messages are not generated more often than every TRIGINT milliseconds; see [Special case of trigger type FIRST](https://www.ibm.com/support/knowledgecenter/en/SSFKSJ_9.0.0/com.ibm.mq.dev.doc/q026940_.htm?view=kc#q026940___q026940_1).
Specify a value in the range 0 - 999,999,999.



[Back to overview of mq_manager](#attributes)
