---
title: mq web
keywords: documentation
layout: documentation
sidebar: mq_config_sidebar
toc: false
---
## Overview

This resource allows you to manage the MQ Web package. This is a singleton resource.
So there is always only one resource available on the system and it is called `mqweb`.
Here is an example on how you should use this:

    mq_web { 'mqweb':
      ensure                                   => 'present',
      http_host                                => 'localhost',
      http_port                                => -1,
      https_port                               => 9443,
      ltpa_cookie_name                         => 'LtpaToken2_${env.MQWEB_LTPA_SUFFIX}',
      ltpa_expiration                          => 120,
      max_msg_trace_file_size                  => 200,
      max_msg_trace_files                      => 5,
      max_trace_file_size                      => 20,
      max_trace_files                          => 10,
      mq_console_autostart                     => true,
      mq_rest_autostart                        => false,
      mq_rest_cors_max_age_in_seconds          => 0,
      mq_rest_csrf_validation                  => true,
      mq_rest_gateway_enabled                  => true,
      mq_rest_messaging_enabled                => true,
      mq_rest_mft_enabled                      => false,
      mq_rest_mft_reconnect_timeout_in_minutes => 30,
      mq_rest_request_timeout                  => 30,
      secure_ltpa                              => true,
      status                                   => 'stopped',
      trace_spec                               => '*=info',
    }

## Attributes



Attribute Name                                                                               | Short Description                                                                                                                                                                                             |
-------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
[ensure](#mq_web_ensure)                                                                     | The basic property that the resource should be in.                                                                                                                                                            |
[http_host](#mq_web_http_host)                                                               | This configuration property is used to specify the HTTP host name as an IP address, domain name server (DNS) host name with domain name suffix, or the DNS host name of the server where IBM MQ is installed. |
[http_port](#mq_web_http_port)                                                               | This configuration property is used to specify the HTTP port number that is used for HTTP connections.                                                                                                        |
[https_port](#mq_web_https_port)                                                             | This configuration property is used to specify the HTTPS port number that is used for HTTPS connections.                                                                                                      |
[ltpa_cookie_name](#mq_web_ltpa_cookie_name)                                                 | This configuration property is used to specify the name of the LTPA token cookie name.                                                                                                                        |
[ltpa_expiration](#mq_web_ltpa_expiration)                                                   | This configuration property is used to specify the time, in seconds, before the LTPA token expires.                                                                                                           |
[max_msg_trace_file_size](#mq_web_max_msg_trace_file_size)                                   | Here is an example on how to use this:
                                                                                                                                                                       |
[max_msg_trace_files](#mq_web_max_msg_trace_files)                                           | This configuration property is used to specify the maximum number of messaging trace files that are generated by the mqweb server for the IBM MQ Console.                                                     |
[max_trace_file_size](#mq_web_max_trace_file_size)                                           | This configuration property is used to specify the maximum size, in MB, that each mqweb server log file can reach.                                                                                            |
[max_trace_files](#mq_web_max_trace_files)                                                   | This configuration property is used to specify the maximum number of mqweb server log files that are generated by the mqweb server.                                                                           |
[mq_console_autostart](#mq_web_mq_console_autostart)                                         | This configuration property is used to specify whether the IBM MQ Console automatically starts when the mqweb server starts.                                                                                  |
[mq_rest_autostart](#mq_web_mq_rest_autostart)                                               | This configuration property is used to specify whether the REST API automatically starts when the mqweb server starts.                                                                                        |
[mq_rest_cors_allowed_origins](#mq_web_mq_rest_cors_allowed_origins)                         | This configuration property is used to specify the origins that are allowed to access the REST API.                                                                                                           |
[mq_rest_cors_max_age_in_seconds](#mq_web_mq_rest_cors_max_age_in_seconds)                   | This configuration property is used to specify the time, in seconds, that a web browser can cache the results of any CORS pre-flight checks.                                                                  |
[mq_rest_csrf_validation](#mq_web_mq_rest_csrf_validation)                                   | This configuration property is used to specify whether CSRF validation checks are performed.                                                                                                                  |
[mq_rest_gateway_enabled](#mq_web_mq_rest_gateway_enabled)                                   | This configuration property is used to specify whether the administrative REST API gateway is enabled.                                                                                                        |
[mq_rest_gateway_qmgr](#mq_web_mq_rest_gateway_qmgr)                                         | This configuration property is used to specify the name of the queue manager to use as the gateway queue manager.                                                                                             |
[mq_rest_messaging_enabled](#mq_web_mq_rest_messaging_enabled)                               | This configuration property is used to specify whether the messaging REST API is enabled.                                                                                                                     |
[mq_rest_mft_coordination_qmgr](#mq_web_mq_rest_mft_coordination_qmgr)                       | This configuration property is used to specify the name of the coordination queue manager from which transfer details are retrieved by the REST API for MFT.                                                  |
[mq_rest_mft_enabled](#mq_web_mq_rest_mft_enabled)                                           | This configuration property is used to specify whether the REST API for MFT is enabled.                                                                                                                       |
[mq_rest_mft_reconnect_timeout_in_minutes](#mq_web_mq_rest_mft_reconnect_timeout_in_minutes) | This configuration property is used to specify the length of time, in minutes, after which the REST API for MFT stops trying to connect to the coordination queue manager.                                    |
[mq_rest_request_timeout](#mq_web_mq_rest_request_timeout)                                   | This configuration property is used to specify the time, in seconds, before a REST request times out.                                                                                                         |
[name](#mq_web_name)                                                                         | Since `mq_web` is a singleton resource, the name is **ALWAYS** `mqweb`
                                                                                                                                       |
[provider](#mq_web_provider)                                                                 | resource.                                                                                                                                                                                                     |
[secure_ltpa](#mq_web_secure_ltpa)                                                           | This configuration property is used to specify whether the LTPA token is secured for all requests.                                                                                                            |
[status](#mq_web_status)                                                                     | With this property you can specify the status of the mqweb server.                                                                                                                                            |
[trace_spec](#mq_web_trace_spec)                                                             | This configuration property is used to specify the level of trace that is generated by the mqweb server.                                                                                                      |




### ensure<a name='mq_web_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of mq_web](#attributes)

### http_host<a name='mq_web_http_host'>

This configuration property is used to specify the HTTP host name as an IP address, domain name server (DNS) host name with domain name suffix, or the DNS host name of the server where IBM MQ is installed.
You can use an asterisk in double quotation marks to specify all available network interfaces.
You can use the value localhost to allow only local connections.
The value for this property is a string value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure    => 'present',
      ...
      http_host => 'localhost',
      ...
    }



[Back to overview of mq_web](#attributes)

### http_port<a name='mq_web_http_port'>

This configuration property is used to specify the HTTP port number that is used for HTTP connections.
You can use a value of -1 to disable the port. The value for this property is an integer value

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure    => 'present',
      ...
      http_port => 8000,
      ...
    }



[Back to overview of mq_web](#attributes)

### https_port<a name='mq_web_https_port'>

This configuration property is used to specify the HTTPS port number that is used for HTTPS connections.
You can use a value of -1 to disable the port. The value for this property is an integer value

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure    => 'present',
      ...
      https_port => 8000,
      ...
    }



[Back to overview of mq_web](#attributes)

### ltpa_cookie_name<a name='mq_web_ltpa_cookie_name'>

This configuration property is used to specify the name of the LTPA token cookie name.
By default, the value of this property is LtpaToken2_${env.MQWEB_LTPA_SUFFIX} on UNIX, Linux, and Windows , or LtpaToken2_${httpsPort} on z/OS, . The variable after the LtpaToken2_ prefix is used by the mqweb server to generate a unique name for the cookie. You cannot set this variable, but you can change the ltpaCookieName to a value of your choosing.
The value for this property is a string value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure           => 'present',
      ...
      ltpa_cookie_name => 'LtpaToken2_${env.MQWEB_LTPA_SUFFIX}',
      ...
    }



[Back to overview of mq_web](#attributes)

### ltpa_expiration<a name='mq_web_ltpa_expiration'>

This configuration property is used to specify the time, in seconds, before the LTPA token expires.
The value for this property is an integer value.
Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure           => 'present',
      ...
      ltpa_expiration => 120,
      ...
    }



[Back to overview of mq_web](#attributes)

### max_msg_trace_file_size<a name='mq_web_max_msg_trace_file_size'>


Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure           => 'present',
      ...
      ltpa_cookie_name => 'LtpaToken2_${env.MQWEB_LTPA_SUFFIX}',
      ...
    }



[Back to overview of mq_web](#attributes)

### max_msg_trace_files<a name='mq_web_max_msg_trace_files'>

This configuration property is used to specify the maximum number of messaging trace files that are generated by the mqweb server for the IBM MQ Console.
The value for this property is a integer value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure              => 'present',
      ...
      max_msg_trace_files => 5,
      ...
    }



[Back to overview of mq_web](#attributes)

### max_trace_file_size<a name='mq_web_max_trace_file_size'>

This configuration property is used to specify the maximum size, in MB, that each mqweb server log file can reach.
The value for this property is an integer value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure              => 'present',
      ...
      max_trace_file_size => 20,
      ...
    }



[Back to overview of mq_web](#attributes)

### max_trace_files<a name='mq_web_max_trace_files'>

This configuration property is used to specify the maximum number of mqweb server log files that are generated by the mqweb server.
The value for this property is an integer value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure           => 'present',
      ...
      max_trace_files  => 10,
      ...
    }



[Back to overview of mq_web](#attributes)

### mq_console_autostart<a name='mq_web_mq_console_autostart'>

This configuration property is used to specify whether the IBM MQ Console automatically starts when the mqweb server starts.
The value for this property is a boolean value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure               => 'present',
      ...
      mq_console_autostart => true,
      ...
    }

Valid values are `true`, `false`. 

[Back to overview of mq_web](#attributes)

### mq_rest_autostart<a name='mq_web_mq_rest_autostart'>

This configuration property is used to specify whether the REST API automatically starts when the mqweb server starts.
The value for this property is a boolean value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure            => 'present',
      ...
      mq_rest_autostart => false,
      ...
    }



[Back to overview of mq_web](#attributes)

### mq_rest_cors_allowed_origins<a name='mq_web_mq_rest_cors_allowed_origins'>

This configuration property is used to specify the origins that are allowed to access the REST API. For more information about CORS, see Configuring CORS for the REST API.
The value for this property is an array of string values.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure           => 'present',
      ...
      mq_rest_cors_allowed_origins => ['site1.example.com','site2.example.com']
      ...
    }



[Back to overview of mq_web](#attributes)

### mq_rest_cors_max_age_in_seconds<a name='mq_web_mq_rest_cors_max_age_in_seconds'>

This configuration property is used to specify the time, in seconds, that a web browser can cache the results of any CORS pre-flight checks.
The value for this property is an integer value.

Here is an example on how to use this:
    mq_web { 'mqweb':
      ensure           => 'present',
      ...
      mq_rest_cors_max_age_in_seconds => 10,
      ...
    }



[Back to overview of mq_web](#attributes)

### mq_rest_csrf_validation<a name='mq_web_mq_rest_csrf_validation'>

This configuration property is used to specify whether CSRF validation checks are performed. A value of false removes the CSRF token validation checks.
The value for this property is a boolean value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure                  => 'present',
      ...
      mq_rest_csrf_validation => true,
      ...
    }



[Back to overview of mq_web](#attributes)

### mq_rest_gateway_enabled<a name='mq_web_mq_rest_gateway_enabled'>


Here is an example on how to use this:
This configuration property is used to specify whether the administrative REST API gateway is enabled.
The value for this property is a boolean value.

    mq_web { 'mqweb':
      ensure                  => 'present',
      ...
      mq_rest_gateway_enabled => true,
      ...
    }



[Back to overview of mq_web](#attributes)

### mq_rest_gateway_qmgr<a name='mq_web_mq_rest_gateway_qmgr'>

This configuration property is used to specify the name of the queue manager to use as the gateway queue manager. This queue manager must be in the same installation as the mqweb server. A blank value indicates that no queue manager is configured as the gateway queue manager.
The value for this property is a string value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure               => 'present',
      ...
      mq_rest_gateway_qmgr => 'MYQM',
      ...
    }



[Back to overview of mq_web](#attributes)

### mq_rest_messaging_enabled<a name='mq_web_mq_rest_messaging_enabled'>

This configuration property is used to specify whether the messaging REST API is enabled.
The value for this property is a boolean value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure                    => 'present',
      ...
      mq_rest_messaging_enabled => true,
      ...
    }



[Back to overview of mq_web](#attributes)

### mq_rest_mft_coordination_qmgr<a name='mq_web_mq_rest_mft_coordination_qmgr'>

This configuration property is used to specify the name of the coordination queue manager from which transfer details are retrieved by the REST API for MFT.
The value for this property is a string value.

Changes to the value of this property take effect when the mqweb server is next started.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure                        => 'present',
      ...
      mq_rest_mft_coordination_qmgr => 'MYQM2',
      ...
    }



[Back to overview of mq_web](#attributes)

### mq_rest_mft_enabled<a name='mq_web_mq_rest_mft_enabled'>

This configuration property is used to specify whether the REST API for MFT is enabled.
The value for this property is a boolean value.

Changes to the value of this property take effect when the mqweb server is next started.  Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure           => 'present',
      ...
      mq_rest_mft_enabled => false,
      ...
    }



[Back to overview of mq_web](#attributes)

### mq_rest_mft_reconnect_timeout_in_minutes<a name='mq_web_mq_rest_mft_reconnect_timeout_in_minutes'>

This configuration property is used to specify the length of time, in minutes, after which the REST API for MFT stops trying to connect to the coordination queue manager.
The value for this property is an integer value.

Changes to the value of this property take effect when the mqweb server is next started.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure           => 'present',
      ...
      mq_rest_mft_reconnect_timeout_in_minutes => 3,
      ...
    }



[Back to overview of mq_web](#attributes)

### mq_rest_request_timeout<a name='mq_web_mq_rest_request_timeout'>

This configuration property is used to specify the time, in seconds, before a REST request times out.
The value for this property is an integer value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure                  => 'present',
      ...
      mq_rest_request_timeout => 30,
      ...
    }



[Back to overview of mq_web](#attributes)

### name<a name='mq_web_name'>

Since `mq_web` is a singleton resource, the name is **ALWAYS** `mqweb`



[Back to overview of mq_web](#attributes)

### provider<a name='mq_web_provider'>

The specific backend to use for this `mq_web`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage MQ Web



[Back to overview of mq_web](#attributes)

### secure_ltpa<a name='mq_web_secure_ltpa'>

This configuration property is used to specify whether the LTPA token is secured for all requests. An unsecured LTPA token is required in order send HTTP requests from a browser.
The value for this property is a boolean value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure      => 'present',
      ...
      secure_ltpa => true,
      ...
    }

Valid values are `true`, `false`. 

[Back to overview of mq_web](#attributes)

### status<a name='mq_web_status'>

With this property you can specify the status of the mqweb server. It can either be running` or
`stopped`.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure           => 'present',
      ...
      status => 'running',
      ...
    }

Valid values are `running`, `stopped`. 

[Back to overview of mq_web](#attributes)

### trace_spec<a name='mq_web_trace_spec'>

This configuration property is used to specify the level of trace that is generated by the mqweb server. For a list of possible values, see Configuring logging for the IBM MQ Console and REST API.
The value for this property is a string value.

Here is an example on how to use this:

    mq_web { 'mqweb':
      ensure     => 'present',
      ...
      trace_spec => '*=info',
      ...
    }



[Back to overview of mq_web](#attributes)
